import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';

class RoundedButton extends StatelessWidget {
  final double radius;
  final double elevation;
  final EdgeInsetsGeometry padding;
  final Color color;
  final Color borderColor;
  final String text;
  final Widget child;
  final TextStyle style;
  final Function onPressed;

  const RoundedButton(
      {this.text,
      this.radius = 18.0,
      this.elevation = 1.0,
      this.color = Colors.red,
      this.padding,
      this.style,
      this.onPressed,
      this.borderColor,
      this.child});

  @override
  Widget build(BuildContext context) {
    return RaisedButton(
      shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(radius),
          side: BorderSide(
              color: onPressed == null
                  ? Theme.of(context).disabledColor
                  : borderColor ?? color)),
      padding: padding ?? Theme.of(context).buttonTheme.padding,
      elevation: elevation,
      focusElevation: 2 * elevation,
      hoverElevation: 2 * elevation,
      highlightElevation: 4 * elevation,
      color: color,
      child: child ??
          Text(
            text,
            style: style ??
                TextStyle(
                  fontSize: 16,
                  color: Colors.white,
                  fontWeight: FontWeight.w800,
                ),
          ),
      onPressed: onPressed,
    );
  }
}

class IconArrowButton extends StatelessWidget {
  final Function onPressed;
  final Widget icon;
  final String text;
  final TextStyle style;
  final MainAxisSize mainAxisSize;

  const IconArrowButton(this.icon, this.text, this.onPressed, {this.mainAxisSize, this.style});

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onPressed,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Divider(
            color: ColorConstants.grayPrimary.withOpacity(0.15),
            thickness: 1,
            height: 1,
          ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 16),
            child: Row(
              mainAxisSize: mainAxisSize ?? MainAxisSize.max,
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                Padding(
                  padding: EdgeInsets.symmetric(vertical: 12),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Padding(padding: EdgeInsets.only(right: 8), child: icon),
                      Text(text ?? '',
                          style: style ?? TextStyle(color: ColorConstants.grayPrimary)),
                    ],
                  ),
                ),
                Icon(
                  Icons.arrow_forward_ios,
                  color: ColorConstants.grayPrimary.withOpacity(0.3),
                  size: 20,
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}
