import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/cached_image/cached_image_network.dart';

class CardItemSupplier extends StatelessWidget {
  final String itemName;
  final int stock;
  final String supplierName;
  final String itemImage;
  final int harga;

  const CardItemSupplier({
    Key key,
    @required this.itemName,
    @required this.stock,
    @required this.supplierName,
    @required this.itemImage,
    @required this.harga,
  })  : assert(itemName != null),
        assert(stock != null),
        assert(supplierName != null),
        assert(itemImage != null),
        assert(harga != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Card(
        color: Colors.white,
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: 12.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            children: <Widget>[
              Expanded(
                  flex: 3,
                  child: Container(
                      alignment: Alignment.center,
                      padding: EdgeInsets.all(10),
                      child: CustomCachedNetworkImage(imageUrl: itemImage))),
              Expanded(
                flex: 6,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceAround,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text(
                      itemName,
                      overflow: TextOverflow.ellipsis,
                      maxLines: 1,
                      style:
                          TextStyle(fontSize: 17, fontWeight: FontWeight.w800),
                    ),
                    RichText(
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis,
                      text: TextSpan(
                          style: TextStyle(
                              fontSize: 17,
                              color: ColorConstants.redSecondary,
                              fontWeight: FontWeight.w700),
                          children: <TextSpan>[
                            TextSpan(
                                text:
                                    '${NumberFormat.currency(symbol: '', decimalDigits: 0).format(harga)}'),
                            TextSpan(
                                text: '/pcs',
                                style: TextStyle(
                                    fontSize: 15,
                                    fontWeight: FontWeight.normal))
                          ]),
                    ),
                    Expanded(child: Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Padding(padding: EdgeInsets.all(4), child:
                        Icon(
                          Icons.storage,
                          color: Colors.black,
                        )),
                        Text('Stok: $stock',
                            overflow: TextOverflow.ellipsis,
                            maxLines: 1,
                            style: TextStyle(fontSize: 14)),
                      ],
                    )),
                    Expanded(child: Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Padding(padding: EdgeInsets.all(4), child:
                        Icon(
                          Icons.work,
                          color: Colors.black,
                        )),
                        Text(supplierName,
                            overflow: TextOverflow.ellipsis,
                            maxLines: 1,
                            style: TextStyle(fontSize: 14)),
                      ],
                    ))
                  ],
                ),
              )
            ],
          ),
        ));
  }
}
