import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class GenericCard extends StatelessWidget {
  final String head;
  final String title;
  final String subtitle;
  final String body;
  final EdgeInsetsGeometry titlePadding;

  const GenericCard(
      {this.head,
      this.title,
      this.subtitle,
      this.body,
      this.titlePadding,
      Key key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Card(
        child: Padding(
            padding: EdgeInsets.symmetric(horizontal: 16.0),
            child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  if (head != null)
                    Padding(
                        padding: EdgeInsetsDirectional.only(top: 16.0),
                        child: Text(head,
                            style: Theme.of(context).textTheme.subtitle2)),
                  if (title != null)
                    Padding(
                        padding: titlePadding ?? EdgeInsets.only(top: 4.0),
                        child: Text(title,
                            style: Theme.of(context).textTheme.headline6)),
                  if (subtitle != null)
                    Padding(
                        padding: titlePadding ?? EdgeInsets.only(top: 2.0),
                        child: Text(subtitle,
                            style: Theme.of(context).textTheme.subtitle2)),
                  if (body != null)
                    Padding(
                      padding: EdgeInsets.only(top: 8.0, bottom: 16.0),
                      child: Text(body,
                          style: Theme.of(context).textTheme.subtitle1),
                    ),
                ])));
  }
}

class StackOfCards extends StatelessWidget {
  final int num;
  final Widget child;
  final double offset;
  final bool vertical;
  final bool horizontal;
  final bool stretch;
  final Color color;

  const StackOfCards(
      {Key key,
      int num = 1,
      @required this.child,
      this.offset = 10.0,
      this.vertical = false,
      this.horizontal = true,
      this.stretch = true,
      this.color = Colors.white})
      : num = num > 0 ? num : 1,
        assert(offset != null),
        super(key: key);

  @override
  Widget build(BuildContext context) => Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Stack(
              children: List<Widget>.generate(
                  num - 1,
                  (val) => Positioned(
                      bottom:
                          vertical ? val * offset : val * offset - (num - 1),
                      left:
                          horizontal ? val * offset : val * offset - (num - 1),
                      top: vertical && !stretch
                          ? (num - val - 1) * offset
                          : val * offset,
                      right: horizontal && !stretch
                          ? (num - val - 1) * offset
                          : val * offset,
                      child: Card(color: color, child: Container()))).toList()
                ..add(
                  Padding(
                    child: child,
                    padding: EdgeInsets.only(
                        bottom: vertical ? (num - 1) * offset : 0,
                        left: horizontal ? (num - 1) * offset : 0),
                  ),
                ),
            )
          ]);
}
