import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/components/bottom_navigation_bar.dart';
import 'package:mobile_apps/src/screens/detail_item_needs/detail_item.dart';
import 'package:mobile_apps/src/screens/home/home_industry/all_home_industry.dart';
import 'package:mobile_apps/src/screens/home/institusi/all_institusi.dart';
import 'package:mobile_apps/src/screens/home/inventories/all_inventories.dart';
import 'package:mobile_apps/src/screens/homeindustry/home_industry.dart';
import 'package:mobile_apps/src/screens/institusi-screen/institusi_screen.dart';
import 'package:fluro/fluro.dart';
import 'package:mobile_apps/src/screens/supplier/all_suppliers.dart';
import 'package:mobile_apps/src/screens/supplier/detailsupplier.dart';
import 'package:mobile_apps/src/screens/supplier/product/detailproduct.dart';
import 'screens/login/login_screen.dart';
import 'screens/notification/notification_screen.dart';

class AppRoute {
  // Add basic routing here
  static String home = '/home';
  static String login = '/login';
  static String notification = '/notification';
  static String recap = '/recap';
  static String allInstitusi = '/allInstitusi';
  static String allSuppliers = '/allSuppliers';
  static String allHomeIndustry = '/allHomeIndustry';

  // Add wildcard routing here
  static String institusi(
          {@required String idInstitusi, @required String namaInstitusi}) =>
      '/institusi/idInstitusi/$idInstitusi/namaInstitusi/$namaInstitusi';
  static String itemNeeded(
          {@required String idInstitusi,
          @required String idItemNeeded,
          @required String namaInstitusi}) =>
      '/itemNeeded/idItemNeeded/$idItemNeeded/idInstitusi/$idInstitusi/namaInstitusi/$namaInstitusi';
  static String detailProductSupplier(
      {@required String idSupplier, @required String idBarang}) {
    return 'supplier/idSupplier/$idSupplier/idBarang/$idBarang';
  }

  static String supplier({
    @required String idSupplier,
  }) =>
      '/supplier/idSupplier/$idSupplier';
  static String homeIndustry({@required String id}) => '/homeindustry/$id';

  static Router router = Router();
  // Make handler for every page
  static final Handler _homeHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          BottomNavigation());
  static final Handler _loginHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          LoginScreen());
  static final Handler _notificationHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          NotificationScreen());
  static final Handler _recapHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          AllInventoriesWidget());
  static final Handler _allInstitusiHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          AllInstitusiWidget());
  static final Handler _allSuppliersHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          AllSuppliersWidget());

  static final Handler _institusiHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          InstitusiScreen(
              namaInstitusi: changeEscapedString(params['namaInstitusi'][0]),
              idInstitusi: params['idInstitusi'][0]));
  static final Handler _itemNeededHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          DetailItemNeeds(
              idInstitusi: params['idInstitusi'][0],
              idItemNeeded: params['idItemNeeded'][0],
              institusiName: changeEscapedString(params['namaInstitusi'][0])));
  static final Handler _detailProductSupplierHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          DetailProductSupplier(
            idBarang: params['idBarang'][0],
            idSupplier: params['idSupplier'][0],
          ));

  static final Handler _supplierHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          DetailSupplier(
            idSupplier: params['idSupplier'][0],
          ));
  static final Handler _homeIndustryHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          HomeIndustryPage(id: params['id'][0]));
  static final Handler _allHomeIndustryHandler = Handler(
      handlerFunc: (BuildContext context, Map<String, dynamic> params) =>
          AllHomeIndustry());
  static void setupRouter() {
    // define all route here
    router.define(
      '/home',
      handler: _homeHandler,
    );
    router.define(
      '/login',
      handler: _loginHandler,
    );
    router.define('/notification', handler: _notificationHandler);
    router.define('/recap', handler: _recapHandler);
    router.define('/allInstitusi', handler: _allInstitusiHandler);
    router.define('/allSuppliers', handler: _allSuppliersHandler);
    router.define(
        '/institusi/idInstitusi/:idInstitusi/namaInstitusi/:namaInstitusi',
        handler: _institusiHandler);
    router.define(
        '/itemNeeded/idItemNeeded/:idItemNeeded/idInstitusi/:idInstitusi/namaInstitusi/:namaInstitusi',
        handler: _itemNeededHandler);
    router.define('supplier/idSupplier/:idSupplier/idBarang/:idBarang',
        handler: _detailProductSupplierHandler);
    router.define(
        '/supplier/idSupplier/:idSupplier',
        handler: _supplierHandler);
    router.define('/homeindustry/:id', handler: _homeIndustryHandler);
    router.define('/allHomeIndustry', handler: _allHomeIndustryHandler);
  }

  static String changeEscapedString(text) => Uri.decodeComponent(text);
}
