import 'package:flutter/material.dart';
import 'package:flutter/painting.dart';
import 'package:flutter/scheduler.dart';
import 'package:intl/intl.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/common/functions.dart';
import 'package:mobile_apps/src/components/cached_image/cached_image_network.dart';
import 'package:mobile_apps/src/models/item.dart';
import 'package:mobile_apps/src/models/item_needed.dart';
import 'package:mobile_apps/src/repositories/item_needed_repositories.dart';

import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';

class DetailItemNeeds extends StatelessWidget {
  final String idInstitusi;
  final String idItemNeeded;
  final String institusiName;

  const DetailItemNeeds(
      {Key key,
      @required this.idInstitusi,
      @required this.idItemNeeded,
      @required this.institusiName})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    final itemNeededRepo = ItemNeededRepository(
        idInstitusi: idInstitusi, idItemNeeded: idItemNeeded);
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: Text(institusiName),
          centerTitle: true,
          actions: <Widget>[
            IconButton(
              icon: Icon(Icons.share),
              onPressed: () => shareScreenshot(context, institusiName),
            ),
            IconButton(icon: Icon(Icons.notifications), onPressed: () {})
          ],
        ),
        body: StreamBuilder(
          stream: itemNeededRepo.itemNeededDocument.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            ;
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            ;
            final itemNeeded = itemNeededRepo.itemNeeded(snapshot);
            final itemRepo = ItemRepository();
            return StreamBuilder(
              stream: itemRepo
                  .itemDocumentFromPath(path: itemNeeded.itemPath)
                  .snapshots(),
              builder: (_, snapshotItem) {
                if (snapshotItem.hasError) {
                  SchedulerBinding.instance.addPostFrameCallback((_) {
                    Scaffold.of(context).showErrorSnackBar(
                        'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                  });
                }
                ;
                if (snapshotItem.connectionState == ConnectionState.waiting) {
                  return Center(child: CircularProgressIndicator());
                }
                ;
                final item = itemRepo.item(snapshotItem);
                return _BodyItemNeed(itemNeeded: itemNeeded, item: item);
              },
            );
          },
        ));
  }
}

class _BodyItemNeed extends StatelessWidget {
  final ItemNeeded itemNeeded;
  final Item item;
  const _BodyItemNeed({
    Key key,
    @required this.itemNeeded,
    @required this.item,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(
          horizontal: MarginConstants.horizontalFromScreen,
          vertical: MarginConstants.verticalFromScreen),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Expanded(
            flex: 1,
            child: CustomCachedNetworkImage(imageUrl: item.url),
          ),
          Expanded(
            flex: 3,
            child: Padding(
              padding: const EdgeInsets.only(top: 40),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  _LabelValueDescription(
                    label: 'Nama Barang',
                    value: item.nama,
                  ),
                  _LabelValueDescription(
                      label: 'Kuantitas Kebutuhan',
                      value: '${itemNeeded.kebutuhan}'),
                  _LabelValueDescription(
                      label: 'Kuantitas terpenuhi',
                      value: '${itemNeeded.terpenuhi}'),
                  _LabelValueDescription(
                      label: 'Periode Kebutuhan',
                      value:
                          '${DateFormat('dd MMMM').format(itemNeeded.periodeMulai)} - '
                          '${DateFormat('dd MMMM yyyy').format(itemNeeded.periodeTerakhir)}'),
                  _LabelValueDescription(
                    label: 'Spesifikasi',
                    value: item.deskripsi,
                  ),
                  _LabelValueDescription(label: 'Manfaat', value: item.manfaat)
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}

class _LabelValueDescription extends StatelessWidget {
  final String label;
  final String value;

  const _LabelValueDescription(
      {Key key, @required this.label, @required this.value})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Text(
          label,
          style: TextStyle(fontWeight: FontWeight.w800),
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
        Text(
          value,
          style: TextStyle(fontSize: 18),
          maxLines: 3,
          overflow: TextOverflow.ellipsis,
        )
      ],
    );
  }
}
