import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/repositories/home_industry_repository.dart';
// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/screens/home/home_industry/home_industry.dart';

class AllHomeIndustry extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(title: 'Home Industry'),
      body: SingleChildScrollView(
        padding: EdgeInsets.symmetric(
            horizontal: MarginConstants.horizontalFromScreen,
            vertical: MarginConstants.verticalFromScreen),
        child: _AllHomeIndustryBody(),
      ),
    );
  }
}

class _AllHomeIndustryBody extends StatefulWidget {
  @override
  __AllHomeIndustryBodyState createState() => __AllHomeIndustryBodyState();
}

class __AllHomeIndustryBodyState extends State<_AllHomeIndustryBody> {
  List homeIndustries = [];
  List currentSearch;

  void updateSearch(String text) {
    var tempList = homeIndustries.where((homeIndustry) {
      var search =
          homeIndustry.nama.toLowerCase() + homeIndustry.alamat.toLowerCase();
      return search.contains(text.toLowerCase());
    });
    setState(() {
      currentSearch = List.from(tempList);
    });
  }

  @override
  Widget build(BuildContext context) {
    final repository = HomeIndustryRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: Text(
              'Home Industry',
              style: Theme.of(context).textTheme.headline5,
            )),
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: Text(
              'Home Industry dapat memproduksi produk medis sesuai permintaan (pre-order). Lihat daftar home industry dan produknya di sini.',
              style: Theme.of(context).textTheme.caption,
            )),
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: TextField(
              onChanged: updateSearch,
              decoration: InputDecoration(
                  labelText: 'Cari nama home industry',
                  hintText: 'Cari nama home industry',
                  prefixIcon: Icon(Icons.search),
                  border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(Radius.circular(25.0)))),
            )),
        StreamBuilder(
          stream: repository.homeIndustryCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            homeIndustries = repository.semuaHomeIndustry(snapshot).toList();
            var shown = currentSearch ?? homeIndustries;
            return Column(
              children: [
                ...shown
                    .map((homeIndustry) => HomeIndustryWidget(
                          homeIndustry: homeIndustry,
                        ))
                    .toList(),
              ],
            );
          },
        ),
      ],
    );
  }
}
