import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/repositories/home_industry_repository.dart';
// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/routes.dart';
import 'package:mobile_apps/src/screens/home/home_industry/home_industry.dart';

class ListHomeIndustry extends StatefulWidget {
  @override
  _ListHomeIndustryState createState() => _ListHomeIndustryState();
}

class _ListHomeIndustryState extends State<ListHomeIndustry> {
  @override
  Widget build(BuildContext context) {
    final repository = HomeIndustryRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: Text(
                  'Home Industry',
                  style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
                )),
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pushNamed(AppRoute.allHomeIndustry);
                  },
                  child: Text(
                    'Lihat Semua',
                    style: TextStyle(color: ColorConstants.redPrimary),
                  ),
                )),
          ],
        ),
        StreamBuilder(
          stream: repository.homeIndustryCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            final semuaHomeIndustry =
                repository.semuaHomeIndustry(snapshot).take(3).toList();
            return Container(
              height: MediaQuery.of(context).size.height * 0.265,
              child: ListView.builder(
                itemBuilder: (BuildContext context, int index) {
                  return HomeIndustryWidget(
                    homeIndustry: semuaHomeIndustry[index],
                  );
                },
                itemCount: semuaHomeIndustry.length,
                shrinkWrap: true,
                scrollDirection: Axis.horizontal,
              ),
            );
          },
        ),
      ],
    );
  }
}
