import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/repositories/institusi_repository.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';

import 'institusi.dart';

class AllInstitusiWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(title: 'Semua Institusi'),
      body: ListView(
        padding: EdgeInsets.symmetric(
            horizontal: MarginConstants.horizontalFromScreen,
            vertical: MarginConstants.verticalFromScreen),
        children: <Widget>[
          _AllInstitusiBody(),
        ],
      ),
    );
  }
}

class _AllInstitusiBody extends StatefulWidget {
  @override
  _AllInstitusiBodyState createState() => _AllInstitusiBodyState();
}

class _AllInstitusiBodyState extends State<_AllInstitusiBody> {
  List semuaInstitusi = [];
  List currentSearch;

  void updateSearch(String text) {
    var tempList = semuaInstitusi.where((institusi) {
      var search =
          institusi.nama.toLowerCase() + institusi.alamat.toLowerCase();
      return search.contains(text.toLowerCase());
    });
    setState(() {
      currentSearch = List.from(tempList);
    });
  }

  @override
  Widget build(BuildContext context) {
    final repository = InstitusiRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: Text(
              'Rumah Sakit & Klinik',
              style: Theme.of(context).textTheme.headline5,
            )),
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: Text(
              'Rumah Sakit dan Klinik kesulitan memenuhi kebutuhan-kebutuhannya. Lihat daftar rumah sakit dan kebutuhannya di sini.',
              style: Theme.of(context).textTheme.caption,
            )),
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: TextField(
              onChanged: updateSearch,
              decoration: InputDecoration(
                  labelText: 'Cari nama rumah sakit',
                  hintText: 'Cari nama rumah sakit',
                  prefixIcon: Icon(Icons.search),
                  border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(Radius.circular(25.0)))),
            )),
        StreamBuilder(
          stream: repository.institusiCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            semuaInstitusi = repository.semuaInstitusi(snapshot).toList();
            var shown = currentSearch ?? semuaInstitusi;
            return Column(
              children: [
                ...shown
                    .map((institusi) => InstitusiWidget(
                          institusi: institusi,
                        ))
                    .toList(),
              ],
            );
          },
        ),
      ],
    );
  }
}
