import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/repositories/institusi_repository.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';

import '../../../routes.dart';
import 'institusi.dart';

class ListInstitusiWidget extends StatefulWidget {
  @override
  _ListInstitusiWidgetState createState() => _ListInstitusiWidgetState();
}

class _ListInstitusiWidgetState extends State<ListInstitusiWidget> {
  // List semuaInstitusi = [];
  @override
  Widget build(BuildContext context) {
    final repository = InstitusiRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: Text(
                  'Rumah Sakit & Klinik',
                  style: TextStyle(fontWeight: FontWeight.bold, fontSize: 20),
                )),
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pushNamed(AppRoute.allInstitusi);
                  },
                  child: Text(
                    'Lihat Semua',
                    style: TextStyle(color: ColorConstants.redPrimary),
                  ),
                )),
          ],
        ),
        StreamBuilder(
          stream: repository.institusiCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            final semuaInstitusi = repository.semuaInstitusi(snapshot).take(3).toList();
            return Container(
              height: MediaQuery.of(context).size.height * 0.265,
              child: ListView.builder(
                itemBuilder: (BuildContext context, int index) {
                  return InstitusiWidget(
                    institusi: semuaInstitusi[index],
                  );
                },
                itemCount: semuaInstitusi.length,
                shrinkWrap: true,
                scrollDirection: Axis.horizontal,
              ),
            );
          },
        ),
      ],
    );
  }
}
