import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/repositories/inventory_repository.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';

import 'inventory.dart';

class AllInventoriesWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(title: 'Semua Inventaris'),
      body: Container(
        padding: EdgeInsets.symmetric(
            horizontal: MarginConstants.horizontalFromScreen,
            vertical: MarginConstants.verticalFromScreen),
        child: _AllInventoryBody(),
      ),
    );
  }
}

class _AllInventoryBody extends StatefulWidget {
  @override
  __AllInventoryBodyState createState() => __AllInventoryBodyState();
}

class __AllInventoryBodyState extends State<_AllInventoryBody> {
  InventoryRepository repository;
  Query inventoriesCollections;
  String fieldSelected;
  bool descending;

  @override
  void initState() {
    repository = InventoryRepository();
    inventoriesCollections = repository.inventoriesCollections;
    descending = true;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (fieldSelected != null) {
      inventoriesCollections = repository.inventoriesCollections;
      inventoriesCollections =
          inventoriesCollections.orderBy(fieldSelected, descending: descending);
    } else {
      inventoriesCollections = repository.inventoriesCollections;
    }
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        Expanded(
          flex: 1,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                'Rekap Siaga Wabah',
                style: TextStyle(fontWeight: FontWeight.w600, fontSize: 20),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: <Widget>[
                  Padding(
                    padding: const EdgeInsets.only(right: 10),
                    child: GestureDetector(
                      onTap: () {
                        showModalBottomSheet(
                            context: context,
                            builder: (context) => sortModal(),
                            backgroundColor: Colors.transparent,
                            isScrollControlled: true);
                      },
                      child: Row(
                        children: <Widget>[Icon(Icons.sort), Text('Sort')],
                      ),
                    ),
                  ),
                  Row(
                    children: <Widget>[Icon(Icons.filter_list), Text('Filter')],
                  )
                ],
              )
            ],
          ),
        ),
        Expanded(
          flex: 10,
          child: StreamBuilder<QuerySnapshot>(
            stream: inventoriesCollections.snapshots(),
            builder: (_, snapshot) {
              if (snapshot.hasError) {
                SchedulerBinding.instance.addPostFrameCallback((_) {
                  Scaffold.of(context).showErrorSnackBar(
                      'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                });
              }
              if (snapshot.connectionState == ConnectionState.waiting) {
                return Center(child: CircularProgressIndicator());
              }
              final inventories = repository.inventories(snapshot);
              return ListView.builder(
                  itemCount: inventories.length,
                  itemBuilder: (BuildContext context, int index) {
                    return InventoryWidget(inventories[index]);
                  });
            },
          ),
        )
      ],
    );
  }

  Widget sortModal() {
    return StatefulBuilder(
      builder: (context, setStateModal) {
        return Container(
          height: MediaQuery.of(context).size.height / 3,
          padding: EdgeInsets.symmetric(horizontal: 10),
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.only(
              topLeft: const Radius.circular(25.0),
              topRight: const Radius.circular(25.0),
            ),
          ),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  Expanded(
                    flex: 2,
                    child: DropdownButton<String>(
                        value: fieldSelected,
                        style: TextStyle(
                            color: ColorConstants.redPrimary,
                            fontSize: 18,
                            fontWeight: FontWeight.w700,
                            decorationStyle: TextDecorationStyle.solid,
                            decorationColor: ColorConstants.bluePrimary,
                            decorationThickness: 2),
                        icon: Icon(Icons.arrow_downward,
                            color: ColorConstants.bluePrimary),
                        underline: Container(
                          height: 2,
                          color: ColorConstants.bluePrimary,
                        ),
                        items: <String>['terpenuhi', 'kebutuhan']
                            .map<DropdownMenuItem<String>>(
                                (String e) => DropdownMenuItem<String>(
                                      child: Text(
                                        e.toUpperCase(),
                                      ),
                                      value: e,
                                    ))
                            .toList(),
                        hint: Text(
                          'Sort by',
                          style: TextStyle(color: ColorConstants.bluePrimary),
                        ),
                        iconSize: 24,
                        onChanged: (val) {
                          setStateModal(() {
                            fieldSelected = val;
                          });
                          setState(() {
                            fieldSelected = val;
                          });
                        }),
                  ),
                  Expanded(
                    flex: 2,
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        RadioListTile<bool>(
                          title: const Text('Ascending'),
                          value: false,
                          groupValue: descending,
                          onChanged: (bool value) {
                            setStateModal(() {
                              descending = value;
                              fieldSelected = fieldSelected ?? 'kebutuhan';
                            });
                            setState(() {
                              fieldSelected = fieldSelected ?? 'kebutuhan';
                              descending = value;
                            });
                          },
                        ),
                        RadioListTile<bool>(
                          title: const Text('Descending'),
                          value: true,
                          groupValue: descending,
                          onChanged: (bool value) {
                            setStateModal(() {
                              descending = value;
                              fieldSelected = fieldSelected ?? 'kebutuhan';
                            });
                            setState(() {
                              fieldSelected = fieldSelected ?? 'kebutuhan';
                              descending = value;
                            });
                          },
                        ),
                      ],
                    ),
                  )
                ],
              ),
              SizedBox(
                  width: double.infinity,
                  child: RaisedButton(
                    onPressed: () {
                      setStateModal(() {
                        fieldSelected = null;
                      });
                      setState(() {
                        fieldSelected = null;
                      });
                    },
                    child: Text('Clear'),
                    color: ColorConstants.redPrimary,
                    textColor: Colors.white,
                  ))
            ],
          ),
        );
      },
    );
  }
}
