import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/repositories/inventory_repository.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/routes.dart';

import 'inventory.dart';

class InventoriesWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final repository = InventoryRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Text(
          'Rekap Kebutuhan',
          style: TextStyle(fontWeight: FontWeight.w600, fontSize: 20),
        ),
        StreamBuilder(
          stream: repository.inventoriesCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            final inventories = repository.inventories(snapshot).take(3);
            return Column(
              children: [
                ...inventories
                    .map((inventory) => InventoryWidget(inventory))
                    .toList(),
                InkWell(
                  onTap: () {
                      Navigator.of(context).pushNamed(AppRoute.recap);
                    },
                  child: Text(
                    'Lihat Semua',
                    style: TextStyle(color: ColorConstants.redPrimary),
                  ),
                ),
              ],
            );
          },
        )
      ],
    );
  }
}
