import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/progressbar/progressbar.dart';
import 'package:mobile_apps/src/models/inventory.dart';
import 'package:mobile_apps/src/models/item.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';

extension ImageStringExtension on String {
  NetworkImage get networkImage => NetworkImage(this);
}

class InventoryWidget extends StatelessWidget {
  final Inventory inventory;


  const InventoryWidget(this.inventory, {Key key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final itemRepository = ItemRepository();
    return Container(
      margin: EdgeInsets.only(bottom: 8),
      child: Column(
        children: <Widget>[
          Container(
            margin: EdgeInsets.only(bottom: 10),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                StreamBuilder(
                  stream: itemRepository.itemDetail(inventory.itemId).snapshots(),
                  builder: (context, snapshot) {
                    if (snapshot.hasError) {
                      return Text('Error has occured');
                    }
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    final item = Item.fromJson(snapshot.data.data);
                    return Text(
                      item.nama,
                      style: TextStyle(fontWeight: FontWeight.w600, fontSize: 12),
                    );
                  }
                ),
                RichText(
                  text: TextSpan(
                    text: inventory.terpenuhi.toString() + '/',
                    style: TextStyle(fontSize: 12, color: ColorConstants.bluePrimary),
                    children: <TextSpan>[
                      TextSpan(
                          text: inventory.kebutuhan.toString(),
                          style: TextStyle(color: Colors.black)),
                    ],
                  ),
                )
              ],
            ),
          ),
          ProgressBar(inventory.terpenuhi, inventory.kebutuhan)
        ],
      ),
    );
  }
}
