import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';
import 'package:mobile_apps/src/common/functions.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/models/kontak.dart';
import 'package:mobile_apps/src/repositories/kontak_repository.dart';

class KontakWidget extends StatelessWidget {
  final String institusi;

  const KontakWidget({this.institusi, Key key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final repository = KontakRepository();
    final collections = institusi == null
        ? repository.kontakSigapCollections
        : repository.kontakCollections(institusi);
    return Padding(
        padding: EdgeInsets.symmetric(horizontal: 12, vertical: 16),
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Text(
                  'Kontak ${institusi == null ? "Koordinator" : "untuk Donasi"}',
                  style: Theme.of(context).textTheme.headline6),
              StreamBuilder(
                stream: collections.snapshots(),
                builder: (_, snapshot) {
                  if (snapshot.hasError) {
                    SchedulerBinding.instance.addPostFrameCallback((_) {
                      Text('Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                    });
                  }
                  if (snapshot.connectionState == ConnectionState.waiting) {
                    return Center(child: CircularProgressIndicator());
                  }
                  final semuaKontak = repository.semuaKontak(snapshot);
                  return ListView.builder(
                    itemBuilder: (BuildContext context, int index) =>
                        KontakInfo(semuaKontak[index]),
                    itemCount: semuaKontak.length,
                    shrinkWrap: true,
                  );
                },
              )
            ]));
  }
}

class KontakInfo extends StatelessWidget {
  final Kontak kontak;

  const KontakInfo(this.kontak, {Key key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Padding(
              padding: const EdgeInsets.only(top: 20, left: 16, bottom: 16),
              child: ListTile(
                title: Text(
                    kontak.jabatan != null ? kontak.jabatan.toUpperCase() : '',
                    style: Theme.of(context).textTheme.headline6),
                subtitle: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    if (kontak.nama != null)
                      Text(kontak.nama,
                          style: Theme.of(context).textTheme.subtitle2),
                  ],
                ),
              ),
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                if (kontak.telepon != null)
                  KontakButton(
                      Icon(Icons.phone_in_talk),
                      'Telepon ${kontak.telepon}',
                      () => launchURL(kontak.telepon, scheme: 'tel')),
                if (kontak.telepon != null)
                  KontakButton(
                      Icon(MdiIcons.whatsapp),
                      'WhatsApp ${kontak.telepon}',
                      () => launchURL(
                          '//wa.me/${cleanPhoneNumber(kontak.telepon)}',
                          scheme: 'https'))
              ],
            ),
            if (kontak.email != null)
              KontakButton(
                Icon(Icons.mail_outline),
                'E-mail ${kontak.email}',
                () => launchURL(kontak.email, scheme: 'mailto'),
                mainAxisSize: MainAxisSize.max,
              )
          ]),
    );
  }
}

class KontakButton extends IconArrowButton {
  const KontakButton(icon, text, onPressed, {mainAxisSize})
      : super(icon, text, onPressed, mainAxisSize: mainAxisSize);
}
