import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/common/functions.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/repositories/home_industry_repository.dart';
// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/screens/home/kontak/kontak.dart';
import 'package:mobile_apps/src/screens/homeindustry/product/product_home_industry.dart';

class HomeIndustryPage extends StatelessWidget {
  final String id;
  HomeIndustryPage({@required this.id, Key key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    final repository = HomeIndustryRepository();
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(
        title: 'Detail Home Industry',
      ),
      body: SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Container(
              padding: EdgeInsets.symmetric(vertical: 27, horizontal: 20),
              margin: EdgeInsets.only(bottom: 28),
              decoration: BoxDecoration(color: Colors.white),
              child: StreamBuilder(
                  stream: repository.getHomeIndustryDocument(id).snapshots(),
                  builder: (context, snapshot) {
                    if (snapshot.hasError) {
                      SchedulerBinding.instance.addPostFrameCallback((_) {
                        Scaffold.of(context).showErrorSnackBar(
                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                      });
                    }
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    final homeIndustry = repository.homeIndustry(snapshot);
                    return Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        FittedBox(
                            fit: BoxFit.fitWidth,
                            child: Text(
                              homeIndustry.nama,
                              style: TextStyle(
                                  fontSize: 20, fontWeight: FontWeight.bold),
                            )),
                        Container(
                          margin: EdgeInsets.only(bottom: 8),
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: <Widget>[
                              Icon(
                                Icons.home,
                                color: ColorConstants.grayPrimary,
                              ),
                              Container(
                                margin: EdgeInsets.only(left: 9),
                                child: Text(
                                  'Home Industry',
                                  style: TextStyle(fontSize: 12),
                                ),
                              )
                            ],
                          ),
                        ),
                        Row(
                          children: <Widget>[
                            Expanded(
                              flex: 2,
                              child: Text(
                                homeIndustry.alamat,
                                style: TextStyle(fontSize: 12),
                              ),
                            ),
                            Expanded(
                              flex: 1,
                              child: RoundedButton(
                                child: Row(
                                  mainAxisAlignment: MainAxisAlignment.center,
                                  children: <Widget>[
                                    Icon(
                                      Icons.map,
                                      color: ColorConstants.grayPrimary,
                                    ),
                                    Text(
                                      'Maps',
                                      style: TextStyle(
                                          color: ColorConstants.grayPrimary),
                                    )
                                  ],
                                ),
                                elevation: 0,
                                radius: 20,
                                padding: EdgeInsets.symmetric(vertical: 10),
                                color: Colors.transparent,
                                borderColor: ColorConstants.grayPrimary,
                                style: TextStyle(
                                    color: ColorConstants.grayPrimary),
                                onPressed: () => launchURL(
                                    'https://www.google.com/maps/search/?'
                                    'api=1&query='
                                    '${homeIndustry.geoLocation['lat']}'
                                    ',${homeIndustry.geoLocation['long']}'),
                              ),
                            )
                          ],
                        ),
                        InkWell(
                          onTap: () => launchURL(
                              'https://www.google.com/maps/search/rumah+sakit/@${homeIndustry.geoLocation['lat']},${homeIndustry.geoLocation['long']}'),
                          child: Text(
                            'Lihat Rumah Sakit terdekat',
                            style: TextStyle(color: ColorConstants.redPrimary),
                          ),
                        ),
                        Container(
                            margin: EdgeInsets.only(top: 7),
                            child: Text(
                              'Kontak',
                              style: TextStyle(
                                  fontSize: 20, fontWeight: FontWeight.bold),
                            )),
                        StreamBuilder(
                            stream: repository
                                .getAllKontakHomeIndustry(id)
                                .snapshots(),
                            builder: (context, snapshot) {
                              if (snapshot.hasError) {
                                SchedulerBinding.instance
                                    .addPostFrameCallback((_) {
                                  Scaffold.of(context).showErrorSnackBar(
                                      'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                                });
                              }
                              if (snapshot.connectionState ==
                                  ConnectionState.waiting) {
                                return Center(
                                    child: CircularProgressIndicator());
                              }
                              final semuaKontak =
                                  repository.semuaKontakHomeIndustry(snapshot);
                              return Column(
                                children: <Widget>[
                                  ...semuaKontak.map((kontak) {
                                    return Column(
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: <Widget>[
                                        Text(kontak.nama),
                                        if (kontak.telepon != null)
                                          KontakButton(
                                            Icon(Icons.phone_in_talk),
                                            'Telepon ${kontak.telepon}',
                                            () => launchURL(kontak.telepon,
                                                scheme: 'tel'),
                                            mainAxisSize: MainAxisSize.max,
                                          ),
                                        if (kontak.telepon != null)
                                          KontakButton(
                                              Icon(MdiIcons.whatsapp),
                                              'WhatsApp ${kontak.telepon}',
                                              () => launchURL(
                                                    '//wa.me/${cleanPhoneNumber(kontak.telepon)}',
                                                    scheme: 'https',
                                                  ),
                                              mainAxisSize: MainAxisSize.max),
                                        if (kontak.email != null)
                                          KontakButton(
                                            Icon(Icons.mail_outline),
                                            'E-mail ${kontak.email}',
                                            () => launchURL(
                                              kontak.email,
                                              scheme: 'mailto',
                                            ),
                                            mainAxisSize: MainAxisSize.max,
                                          ),
                                      ],
                                    );
                                  })
                                ],
                              );
                            })
                      ],
                    );
                  }),
            ),
            Container(
              margin: EdgeInsets.symmetric(horizontal: 20),
              child: StreamBuilder(
                  stream: repository.getAllProductHomeIndustry(id).snapshots(),
                  builder: (context, snapshot) {
                    if (snapshot.hasError) {
                      SchedulerBinding.instance.addPostFrameCallback((_) {
                        Scaffold.of(context).showErrorSnackBar(
                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                      });
                    }
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    final semuaProduct =
                        repository.semuaProductHomeIndustry(snapshot);
                    return Column(
                      children: <Widget>[
                        ...semuaProduct.map((product) {
                          return ProductHomeIndustryWidget(product: product);
                        })
                      ],
                    );
                  }),
            ),
            Container(
              margin: EdgeInsets.symmetric(horizontal: 20),
              child: Text(
                'Produsen dapat memproduksi produk sesuai permintaan jika bahan baku dan dana tersedia, harap hubungi kontak untuk informasi lebih lanjut.',
                style: TextStyle(fontSize: 12, color: ColorConstants.muteText),
                textAlign: TextAlign.justify,
              ),
            )
          ],
        ),
      ),
    );
  }
}
