import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:intl/intl.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/models/product_home_industry.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';
// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';

class ProductHomeIndustryWidget extends StatelessWidget {
  final ProductHomeIndustry product;

  ProductHomeIndustryWidget({@required this.product, Key key})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    final itemRepository = ItemRepository();
    return Card(
      child: Container(
        margin: EdgeInsets.symmetric(
            vertical: 23, horizontal: MarginConstants.horizontalFromScreen),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceAround,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Container(
              margin: EdgeInsets.only(bottom: 7),
              child: Text(
              "${NumberFormat.simpleCurrency(locale: 'id').format(product.harga)}/pcs",
              style: TextStyle(
                  color: ColorConstants.redSecondary,
                  fontWeight: FontWeight.bold,
                  fontSize: 20),
            ),
            ),
            StreamBuilder(
                stream: itemRepository.itemDocumentFromPath(path: product.idItem).snapshots(),
                builder: (context, snapshot) {
                  if (snapshot.hasError) {
                    SchedulerBinding.instance.addPostFrameCallback((_) {
                      Scaffold.of(context).showErrorSnackBar(
                          'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                    });
                  }
                  if (snapshot.connectionState == ConnectionState.waiting) {
                    return Center(child: CircularProgressIndicator());
                  }
                  final item = itemRepository.item(snapshot);
                  return _description('Jenis Produk', '${item.nama} buah');
                }),
            _description('Kapasitas Produksi',
                '${product.kapasitas} pcs/${product.durasi}'),
            _description('Bahan yang dibutuhkan', '${product.bahan}')
          ],
        ),
      ),
    );
  }

  Widget _description(String title, String description) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Text(
          title,
          style: TextStyle(fontWeight: FontWeight.w600, fontSize: 16),
        ),
        Text(
          description,
          style: TextStyle(fontSize: 16),
        )
      ],
    );
  }
}
