import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/repositories/institusi_repository.dart';
import 'package:mobile_apps/src/screens/home/kontak/kontak.dart';
import 'kebutuhan/kebutuhan.dart';
// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';

class InstitusiScreen extends StatefulWidget {
  final String namaInstitusi;
  final String idInstitusi;

  InstitusiScreen({@required this.namaInstitusi, @required this.idInstitusi});

  @override
  _InstitusiScreenState createState() => _InstitusiScreenState();
}

class _InstitusiScreenState extends State<InstitusiScreen> {
  InstitusiRepository repository = InstitusiRepository();
  Stream<DocumentSnapshot> _stream;
  @override
  void initState() {
    _stream =
        InstitusiRepository().institusiDocument(widget.idInstitusi).snapshots();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(
        title: 'Rekap Kebutuhan',
      ),
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            Container(
              padding: EdgeInsets.only(left: 37, top: 27, bottom: 27),
              color: Colors.white,
              child: StreamBuilder(
                  stream: _stream,
                  builder: (context, snapshot) {
                    if (snapshot.hasError) {
                      SchedulerBinding.instance.addPostFrameCallback((_) {
                        Scaffold.of(context).showErrorSnackBar(
                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                      });
                    }
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    final institusi = repository.institusi(snapshot);
                    return Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        Text(
                          institusi.nama,
                          style: TextStyle(
                              fontWeight: FontWeight.bold, fontSize: 20),
                        ),
                        Text(
                          institusi.alamat,
                          style: TextStyle(fontSize: 12),
                        ),
                        Text(
                          '${institusi.info1} | ${institusi.info2}',
                          style: TextStyle(
                              color: ColorConstants.grayPrimary, fontSize: 12),
                        ),
                        RoundedButton(text: 'Subscribe',
                            elevation: 0.0,
                            padding: EdgeInsets.symmetric(horizontal: 20, vertical: 11),
                            radius: 32.0,
                            style: TextStyle(
                                color: Colors.white,
                                fontSize: 12.0,
                                fontWeight: FontWeight.bold),
                            onPressed: () {})
                      ],
                    );
                  }),
            ),
            Container(
              padding: EdgeInsets.symmetric(
                horizontal: MarginConstants.horizontalFromScreen,
                vertical: MarginConstants.verticalFromScreen,
              ),
              child: Column(
                children: <Widget>[
                  Kebutuhan(
                    idInstitusi: widget.idInstitusi,
                    namaInstitusi: widget.namaInstitusi,
                  ),
                  KontakWidget(institusi: widget.idInstitusi)
                ],
              ),
            )
          ],
        ),
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
  }
}
