import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';
import 'package:mobile_apps/src/repositories/kebutuhan_repository.dart';
import 'package:mobile_apps/src/routes.dart';

class Kebutuhan extends StatelessWidget {
  final String idInstitusi;
  final String namaInstitusi;
  Kebutuhan({@required this.idInstitusi, @required this.namaInstitusi});
  @override
  Widget build(BuildContext context) {
    final kebutuhanRepository = KebutuhanRepository();
    return Card(
      color: Colors.white,
      child: Container(
        margin: EdgeInsets.only(top: 25, left: 13, bottom: 20, right: 14),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Container(
                margin: EdgeInsets.only(bottom: 25),
                child: Text(
                  'Kebutuhan $namaInstitusi',
                  style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
                )),
            StreamBuilder(
              stream: kebutuhanRepository
                  .kebutuhanCollections(idInstitusi)
                  .snapshots(),
              builder: (_, snapshot) {
                if (snapshot.hasError) {
                  SchedulerBinding.instance.addPostFrameCallback((_) {
                    Text('Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                  });
                }
                if (snapshot.connectionState == ConnectionState.waiting) {
                  return Center(child: CircularProgressIndicator());
                }
                final allKebutuhan = kebutuhanRepository.kebutuhan(snapshot);
                return Container(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      ...allKebutuhan.map((item) {
                        return kebutuhanProgress(
                            idItemNeeded: item.id,
                            idItem: item.itemPath,
                            terpenuhi: item.terpenuhi,
                            kebutuhan: item.kebutuhan,
                            context: context);
                      }).toList()
                    ],
                  ),
                );
              },
            )
          ],
        ),
      ),
    );
  }

  Widget kebutuhanProgress(
      {@required String idItemNeeded,
      @required String idItem,
      @required int kebutuhan,
      @required int terpenuhi,
      @required BuildContext context}) {
    final itemRepository = ItemRepository();
    return InkWell(
      onTap: () {
        Navigator.of(context).pushNamed(AppRoute.itemNeeded(
          idInstitusi: idInstitusi,
          idItemNeeded: idItemNeeded,
          namaInstitusi: namaInstitusi,
        ));
      },
      child: Column(
        children: <Widget>[
          Divider(
            color: ColorConstants.grayPrimary.withOpacity(0.15),
            thickness: 1,
            height: 1,
          ),
          Container(
            margin: EdgeInsets.only(left: 7, top: 12, bottom: 12),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                StreamBuilder(
                    stream: itemRepository
                        .itemDocumentFromPath(path: idItem)
                        .snapshots(),
                    builder: (_, snapshot) {
                      if (snapshot.hasError) {
                        SchedulerBinding.instance.addPostFrameCallback((_) {
                          Text(
                              'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                        });
                      }
                      if (snapshot.connectionState == ConnectionState.waiting) {
                        return Center(child: CircularProgressIndicator());
                      }
                      final item = itemRepository.item(snapshot);
                      return Text(
                        item.nama ?? '',
                        style: TextStyle(fontSize: 14),
                        overflow: TextOverflow.ellipsis,
                      );
                    }),
                Row(
                  children: <Widget>[
                    Container(
                      margin: EdgeInsets.only(right: 16),
                      child: RichText(
                        overflow: TextOverflow.ellipsis,
                        text: TextSpan(
                          text: terpenuhi.toString() + '/',
                          style: TextStyle(
                              fontSize: 14, color: ColorConstants.redPrimary),
                          children: <TextSpan>[
                            TextSpan(
                                text: kebutuhan.toString(),
                                style: TextStyle(color: Colors.black)),
                          ],
                        ),
                      ),
                    ),
                    Icon(
                      Icons.arrow_forward_ios,
                      color: ColorConstants.grayPrimary.withOpacity(0.3),
                      size: 20,
                    )
                  ],
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
