import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/card_item_supplier/card_item_supplier.dart';
import 'package:mobile_apps/src/components/input/input_search.dart';
import 'package:mobile_apps/src/models/item_supplier_aggregate.dart';
import 'package:mobile_apps/src/repositories/item_ketersediaan_aggregate_repository.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';
import 'package:mobile_apps/src/repositories/product_supplier_repository.dart';
import 'package:mobile_apps/src/repositories/supplier_repository.dart';
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:mobile_apps/src/routes.dart';

class KetersediaanAgregrasi extends StatefulWidget {
  final fillPercent = 65.23;

  const KetersediaanAgregrasi({Key key}) : super(key: key);
  @override
  _KetersediaanAgregrasiState createState() => _KetersediaanAgregrasiState();
}

class _KetersediaanAgregrasiState extends State<KetersediaanAgregrasi> {
  String _search;
  bool descending;
  String fieldSelected;
  ItemKetersediaanRepository ketersediaanAgregrasiRepo;
  Query ketersediaanAgregrasiCollections;

  Stream<QuerySnapshot> result;

  final List<String> field = ['nama_item', 'nama_supplier', 'stok', 'harga'];

  @override
  void initState() {
    _search = '';
    ketersediaanAgregrasiRepo = ItemKetersediaanRepository();
    ketersediaanAgregrasiCollections =
        ketersediaanAgregrasiRepo.itemCollections;
    descending = true;
    result = ketersediaanAgregrasiCollections.snapshots();
    super.initState();
  }

  void onChange(String s) {
    setState(() {
      _search = s;
    });
  }

  void onChangeQuery() {
    if (fieldSelected != null) {
      ketersediaanAgregrasiCollections =
          ketersediaanAgregrasiRepo.itemCollections;
      ketersediaanAgregrasiCollections = ketersediaanAgregrasiCollections
          .orderBy(fieldSelected, descending: descending);
    } else {
      ketersediaanAgregrasiCollections =
          ketersediaanAgregrasiRepo.itemCollections;
    }
    result = ketersediaanAgregrasiCollections.snapshots();
  }

  @override
  Widget build(BuildContext context) {
    final fillStop = (100 - widget.fillPercent) / 100;
    return Container(
      padding: EdgeInsets.only(
          left: MarginConstants.horizontalFromScreen + 5,
          right: MarginConstants.horizontalFromScreen + 5,
          top: MarginConstants.verticalFromScreen + 5),
      decoration: BoxDecoration(
          gradient: LinearGradient(colors: [
        ColorConstants.redSecondary,
        ColorConstants.redSecondary,
        Colors.white,
        Colors.white
      ], stops: [
        0.0,
        fillStop,
        fillStop,
        1
      ], end: Alignment.bottomCenter, begin: Alignment.topCenter)),
      child: Column(
        children: <Widget>[
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                'Produk Tersedia',
                style: TextStyle(
                    color: Colors.white,
                    fontWeight: FontWeight.w800,
                    fontSize: 18),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.end,
                children: <Widget>[
                  IconButton(
                    icon: Icon(Icons.sort),
                    onPressed: () {
                      showModalBottomSheet(
                          context: context,
                          builder: (context) => sortModal(),
                          backgroundColor: Colors.transparent,
                          isScrollControlled: true);
                    },
                    color: Colors.white,
                  ),
                  IconButton(
                    icon: Icon(Icons.filter_list),
                    onPressed: () {},
                    color: Colors.white,
                  ),
                ],
              ),
            ],
          ),
          InputSearch(
            onChange: onChange,
          ),
          Expanded(
            child: Container(
              constraints: kIsWeb ? BoxConstraints(maxWidth: 600.0) : null,
              margin: kIsWeb
                  ? EdgeInsets.symmetric(vertical: 20)
                  : EdgeInsets.only(top: 20),
              color: Colors.transparent,
              child: StreamBuilder<QuerySnapshot>(
                  stream: result,
                  builder: (context, snapshot) {
                    if (snapshot.hasError) {
                      SchedulerBinding.instance.addPostFrameCallback((_) {
                        Scaffold.of(context).showErrorSnackBar(
                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                      });
                    }
                    ;
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    ;
                    final items = _search == ''
                        ? ketersediaanAgregrasiRepo.allItemAvailable(snapshot)
                        : ketersediaanAgregrasiRepo.allItemSearch(
                            _search, snapshot);
                    return ListView.builder(
                      itemBuilder: (BuildContext context, int index) {
                        return _ItemKetersediaan(
                          itemSupplierAggregate: items[index],
                        );
                      },
                      itemCount: items.length,
                      shrinkWrap: true,
                    );
                  }),
            ),
          )
        ],
      ),
    );
  }

  Widget sortModal() {
    return StatefulBuilder(
      builder: (context, setStateModal) {
        return Container(
          height: MediaQuery.of(context).size.height / 3,
          padding: EdgeInsets.symmetric(horizontal: 10),
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.only(
              topLeft: const Radius.circular(25.0),
              topRight: const Radius.circular(25.0),
            ),
          ),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  Expanded(
                    flex: 2,
                    child: DropdownButton<String>(
                        value: fieldSelected,
                        style: TextStyle(
                            color: ColorConstants.redPrimary,
                            fontSize: 18,
                            fontWeight: FontWeight.w700,
                            decorationStyle: TextDecorationStyle.solid,
                            decorationColor: ColorConstants.bluePrimary,
                            decorationThickness: 2),
                        icon: Icon(Icons.arrow_downward,
                            color: ColorConstants.bluePrimary),
                        underline: Container(
                          height: 2,
                          color: ColorConstants.bluePrimary,
                        ),
                        items: field
                            .map<DropdownMenuItem<String>>(
                                (String e) => DropdownMenuItem<String>(
                                      child: Text(
                                        e.toUpperCase(),
                                      ),
                                      value: e,
                                    ))
                            .toList(),
                        hint: Text(
                          'Sort by',
                          style: TextStyle(color: ColorConstants.bluePrimary),
                        ),
                        iconSize: 24,
                        onChanged: (val) {
                          setStateModal(() {
                            fieldSelected = val;
                          });
                          setState(() {
                            fieldSelected = val;
                            onChangeQuery();
                          });
                        }),
                  ),
                  Expanded(
                    flex: 2,
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        RadioListTile<bool>(
                          title: const Text('Ascending'),
                          value: false,
                          groupValue: descending,
                          onChanged: (bool value) {
                            setStateModal(() {
                              descending = value;
                              fieldSelected = fieldSelected ?? field[0];
                            });
                            setState(() {
                              fieldSelected = fieldSelected ?? field[0];
                              descending = value;
                              onChangeQuery();
                            });
                          },
                        ),
                        RadioListTile<bool>(
                          title: const Text('Descending'),
                          value: true,
                          groupValue: descending,
                          onChanged: (bool value) {
                            setStateModal(() {
                              descending = value;
                              fieldSelected = fieldSelected ?? field[0];
                            });
                            setState(() {
                              fieldSelected = fieldSelected ?? field[0];
                              descending = value;
                              onChangeQuery();
                            });
                          },
                        ),
                      ],
                    ),
                  )
                ],
              ),
              SizedBox(
                  width: double.infinity,
                  child: RaisedButton(
                    onPressed: () {
                      setStateModal(() {
                        fieldSelected = null;
                      });
                      setState(() {
                        fieldSelected = null;
                        onChangeQuery();
                      });
                    },
                    child: Text('Clear'),
                    color: ColorConstants.redPrimary,
                    textColor: Colors.white,
                  ))
            ],
          ),
        );
      },
    );
  }
}

class _ItemKetersediaan extends StatelessWidget {
  final ItemSupplierAggregate itemSupplierAggregate;

  const _ItemKetersediaan({Key key, @required this.itemSupplierAggregate})
      : assert(itemSupplierAggregate != null),
        super(key: key);
  @override
  Widget build(BuildContext context) {
    final supplierRepo = SupplierRepository();
    return SizedBox(
      height: MediaQuery.of(context).size.height / 7,
      child: StreamBuilder<DocumentSnapshot>(
          stream: supplierRepo
              .supplierDocumentFromPath(
                  path: itemSupplierAggregate.supplierPath)
              .snapshots(),
          builder: (context, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            ;
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            ;
            final supplier = supplierRepo.supplier(snapshot);
            final productFromSuppRepo = ProductSupplierRepository();
            return StreamBuilder<DocumentSnapshot>(
                stream: productFromSuppRepo
                    .oneProductFromSupplierPath(
                        path: itemSupplierAggregate.barangPath)
                    .snapshots(),
                builder: (context, snapshot) {
                  if (snapshot.hasError) {
                    SchedulerBinding.instance.addPostFrameCallback((_) {
                      Scaffold.of(context).showErrorSnackBar(
                          'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                    });
                  }
                  ;
                  if (snapshot.connectionState == ConnectionState.waiting) {
                    return Center(child: CircularProgressIndicator());
                  }
                  ;
                  final productSupplier = productFromSuppRepo.product(snapshot);
                  final itemRepo = ItemRepository();
                  return StreamBuilder<DocumentSnapshot>(
                      stream: itemRepo
                          .itemDocumentFromPath(path: productSupplier.idItem)
                          .snapshots(),
                      builder: (context, snapshot) {
                        if (snapshot.hasError) {
                          SchedulerBinding.instance.addPostFrameCallback((_) {
                            Scaffold.of(context).showErrorSnackBar(
                                'Oops! Ada sesuatu yang salah, mohon coba lagi '
                                'ya.');
                          });
                        }
                        ;
                        if (snapshot.connectionState ==
                            ConnectionState.waiting) {
                          return Center(child: CircularProgressIndicator());
                        }
                        ;
                        final item = itemRepo.item(snapshot);
                        return GestureDetector(
                          onTap: () {
                            Navigator.of(context).pushNamed(
                                AppRoute.detailProductSupplier(
                                    idSupplier: supplier.id,
                                    idBarang: productSupplier.id));
                          },
                          child: CardItemSupplier(
                            harga: productSupplier.harga,
                            itemName: item.nama,
                            stock: productSupplier.stok,
                            supplierName: supplier.nama,
                            itemImage: item.url,
                          ),
                        );
                      });
                });
          }),
    );
  }
}
