import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:provider/provider.dart';

import '../../routes.dart';
import '../../services/auth_service.dart';

class LoginScreen extends StatefulWidget {
  @override
  _LoginScreenState createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen> {
  bool isLoading = false;

  void onGoogleSignInButtonPressed(
      BuildContext context, AuthService authService) async {
    final googleSignIn = GoogleSignIn();
    try {
      setState(() => isLoading = true);
      if (await googleSignIn.isSignedIn()) await googleSignIn.disconnect();
      final account = await googleSignIn.signIn();
      if (account == null) throw 'Mohon masuk menggunakan Akun Google';
      await authService.authenticate(account);
      setState(() => isLoading = false);
    } catch (e) {
      Scaffold.of(context).showSnackBar(
        SnackBar(
          content: Text('Terjadi kesalahan, mohon masuk menggunakan Akun Google'),
        ),
      );
      setState(() => isLoading = false);
    }
    if (authService.isAuthenticated) {
      await Navigator.of(context).pushNamedAndRemoveUntil(AppRoute.home, (_) => false);
    }
  }

  @override
  Widget build(BuildContext context) {
    final authService = Provider.of<AuthService>(context);
    return Scaffold(
      body: Builder(
        builder: (BuildContext context) => Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Container(
                margin: EdgeInsets.symmetric(vertical: 8.0),
                child: Text('Siaga Wabah',
                    style: Theme.of(context).textTheme.headline3),
              ),
              OutlineButton(
                onPressed: isLoading
                    ? null
                    : () => onGoogleSignInButtonPressed(context, authService),
                color: Colors.pink,
                highlightColor: Colors.blue,
                child: Padding(
                  padding: EdgeInsets.all(16.0),
                  child: Row(
                    mainAxisSize: MainAxisSize.min,
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: <Widget>[
                      isLoading
                          ? CircularProgressIndicator()
                          : Image(
                              image:
                                  AssetImage('assets/images/google_logo.png'),
                              height: 24.0,
                            ),
                      Container(
                        margin: const EdgeInsets.only(left: 10),
                        child: Text(
                          'Sign in with Google',
                        ),
                      )
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
