import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/repositories/notifikasi_repository.dart';
import 'package:mobile_apps/src/screens/notification/notifikasi.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';

class NotificationScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final repository = NotifikasiRepository();
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(title: 'Notifikasi'),
      body: Container(
        padding: EdgeInsets.symmetric(
          horizontal: MarginConstants.horizontalFromScreen,
          vertical: MarginConstants.verticalFromScreen
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            Expanded(
              child: StreamBuilder(
                stream: repository.notifikasiCollections.orderBy('waktu', descending: true).snapshots(),
                builder: (_, snapshot) {
                  if (snapshot.hasError) {
                    SchedulerBinding.instance.addPostFrameCallback((_) {
                      Scaffold.of(context).showErrorSnackBar(
                          'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                    });
                  }
                  if (snapshot.connectionState == ConnectionState.waiting) {
                    return Center(child: CircularProgressIndicator());
                  }
                  final semuaNotifikasi = repository.semuaNotifikasi(snapshot);
                  return ListView.builder(
                    itemCount: semuaNotifikasi.length,
                    itemBuilder: (BuildContext context, int index) {
                      return NotifikasiWidget(semuaNotifikasi[index]);
                    }
                  );
                },
              ),
            )
          ],
        ),
      ),
    );
  }
}
