import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/repositories/supplier_repository.dart';
import 'package:mobile_apps/src/screens/supplier/supplier.dart';

class AllSuppliersWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(title: 'Semua Supplier'),
      body: ListView(
        scrollDirection: Axis.vertical,
        padding: EdgeInsets.symmetric(
            horizontal: MarginConstants.horizontalFromScreen,
            vertical: MarginConstants.verticalFromScreen),
        children: <Widget>[
          _AllSuppliersBody(),
        ],
      ),
    );
  }
}

class _AllSuppliersBody extends StatefulWidget {
  @override
  _AllSuppliersBodyState createState() => _AllSuppliersBodyState();
}

class _AllSuppliersBodyState extends State<_AllSuppliersBody> {
  List semuaSupplier = [];
  List currentSearch;

  void updateSearch(String text) {
    var tempList = semuaSupplier.where((supplier) {
      var search =
          supplier.nama.toLowerCase() + supplier.alamat.toLowerCase();
      return search.contains(text.toLowerCase());
    });
    setState(() {
      currentSearch = List.from(tempList);
    });
  }

  @override
  Widget build(BuildContext context) {
    final repository = SupplierRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: Text(
              'Supplier',
              style: Theme.of(context).textTheme.headline5,
            )),
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: Text(
              'Supplier adalah penyedia bahan dan alat medis ready stock. Lihat daftar supplier dan daftar produk yang mereka jual disini.',
              style: Theme.of(context).textTheme.caption,
            )),
        Padding(
            padding: EdgeInsets.only(bottom: 12.0),
            child: TextField(
              onChanged: updateSearch,
              decoration: InputDecoration(
                  labelText: 'Cari nama supplier',
                  hintText: 'Cari nama supplier',
                  prefixIcon: Icon(Icons.search),
                  border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(Radius.circular(25.0)))),
            )),
        StreamBuilder(
          stream: repository.supplierCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            semuaSupplier =
                repository.semuaSupplier(snapshot).toList();
            var shown = currentSearch ?? semuaSupplier;
            return Column(
              children: [
                ...shown
                    .map((supplier) => SupplierWidget(supplier: supplier))
                    .toList(),
              ],
            );
          },
        ),
      ],
    );
  }
}
