import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/common/functions.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/repositories/supplier_repository.dart';
import 'package:mobile_apps/src/screens/home/kontak/kontak.dart';
// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/screens/supplier/tabs.dart';

class DetailSupplier extends StatefulWidget {
  final String idSupplier;
  // final String url;

  DetailSupplier({
    @required this.idSupplier,
    // @required this.url
  });

  @override
  _DetailSupplierState createState() => _DetailSupplierState();
}

class _DetailSupplierState extends State<DetailSupplier> {
  @override
  Widget build(BuildContext context) {
    final repository = SupplierRepository();
    return Scaffold(
      backgroundColor: ColorConstants.backgroundColor,
      appBar: SigapAppBar(
        title: 'Detail Supplier',
      ),
      body: ListView(
        shrinkWrap: true,
        children: <Widget>[
          StreamBuilder(
              stream: repository
                  .supplierDocument(idSupplier: widget.idSupplier)
                  .snapshots(),
              builder: (context, snapshot) {
                if (snapshot.hasError) {
                  SchedulerBinding.instance.addPostFrameCallback((_) {
                    Scaffold.of(context).showErrorSnackBar(
                        'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                  });
                }
                if (snapshot.connectionState == ConnectionState.waiting) {
                  return Center(child: CircularProgressIndicator());
                }
                final supplier = repository.supplier(snapshot);
                return Container(
                    child: Padding(
                  padding: const EdgeInsets.symmetric(
                      horizontal: MarginConstants.horizontalFromScreen,
                      vertical: 20),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.symmetric(vertical: 8.0),
                        child: Text(supplier.nama,
                            style: TextStyle(
                                fontWeight: FontWeight.bold, fontSize: 20)),
                      ),
                      Row(
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: <Widget>[
                          Icon(
                            Icons.store,
                            color: Colors.black,
                          ),
                          Padding(
                            padding: EdgeInsets.only(left: 4),
                            child: Text('Perusahaan Terbuka'),
                          )
                        ],
                      ),
                      Row(
                        children: <Widget>[
                          Expanded(
                            flex: 2,
                            child: Text(
                              supplier.alamat,
                              style: TextStyle(fontSize: 12),
                            ),
                          ),
                          Expanded(
                            flex: 1,
                            child: RoundedButton(
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                children: <Widget>[
                                  Icon(
                                    Icons.map,
                                    color: ColorConstants.grayPrimary,
                                  ),
                                  Text(
                                    'Maps',
                                    style: TextStyle(
                                        color: ColorConstants.grayPrimary),
                                  )
                                ],
                              ),
                              elevation: 0,
                              radius: 20,
                              padding: EdgeInsets.symmetric(vertical: 10),
                              color: Colors.transparent,
                              borderColor: ColorConstants.grayPrimary,
                              style:
                                  TextStyle(color: ColorConstants.grayPrimary),
                              onPressed: () => launchURL(
                                  'https://www.google.com/maps/search/?'
                                  'api=1&query='
                                  '${supplier.geoLocation['lat']}'
                                  ',${supplier.geoLocation['long']}'),
                            ),
                          )
                        ],
                      ),
                      InkWell(
                        onTap: () => launchURL(
                            'https://www.google.com/maps/search/rumah+sakit/@${supplier.geoLocation['lat']},${supplier.geoLocation['long']}'),
                        child: Text(
                          'Lihat Rumah Sakit terdekat',
                          style: TextStyle(color: ColorConstants.redPrimary),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.only(top: 16.0),
                        child: Text(
                          'Kontak',
                          style: TextStyle(
                              fontSize: 16, fontWeight: FontWeight.w600),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(vertical: 8.0),
                        child: Text(supplier.sales),
                      ),
                      if (supplier.telepon != null)
                        KontakButton(
                            Icon(Icons.phone_in_talk),
                            'Telepon ${supplier.telepon}',
                            () => launchURL(supplier.telepon, scheme: 'tel')),
                      if (supplier.telepon != null)
                        KontakButton(
                            Icon(MdiIcons.whatsapp),
                            'WhatsApp ${supplier.telepon}',
                            () => launchURL(
                                  '//wa.me/${cleanPhoneNumber(supplier.telepon)}',
                                  scheme: 'https',
                                )),
                      Padding(
                          padding: EdgeInsets.only(top: 32.0),
                          child: SupplierTabs(
                              idSupplier: widget.idSupplier,
                              namaSupplier: supplier.nama)),
                    ],
                  ),
                ));
              }),
        ],
      ),
    );
  }
}
