import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/functions.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/repositories/dokumen_repository.dart';

class ListDokumenWidget extends StatelessWidget {
  final String idSupplier;

  const ListDokumenWidget(this.idSupplier, {Key key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final repository = DokumenRepository();
    final snapshots = repository.dokumenSnapshots(idSupplier);
    return Column(crossAxisAlignment: CrossAxisAlignment.start, children: <
        Widget>[
      Padding(
          padding: EdgeInsets.only(bottom: 12.0),
          child: Text(
            'Dokumen Pendukung',
            style: Theme.of(context)
                .textTheme
                .headline5
                .copyWith(color: Colors.white),
          )),
      Flexible(
          child: Card(
              child: StreamBuilder(
                  stream: snapshots,
                  builder: (_, snapshot) {
                    if (snapshot.hasError) {
                      SchedulerBinding.instance.addPostFrameCallback((_) {
                        Text(
                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                      });
                    }
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    final allDokumen = repository.allDokumen(snapshot);
                    if (allDokumen.isEmpty) {
                      return Container(
                          width: double.infinity,
                          padding: EdgeInsets.all(12.0),
                          child: Text('Belum ada dokumen.',
                              style: Theme.of(context).textTheme.subtitle1));
                    }
                    return ListView.builder(
                      itemBuilder: ((context, index) {
                        final dokumen = allDokumen[index];
                        return IconArrowButton(
                            null, dokumen.nama, () => launchURL(dokumen.link),
                            mainAxisSize: MainAxisSize.max,
                            style: TextStyle(color: Colors.black));
                      }),
                      itemCount: allDokumen.length,
                      shrinkWrap: true,
                    );
                  })))
    ]);
  }
}
