import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/card_item_supplier/card_item_supplier.dart';
import 'package:mobile_apps/src/components/input/input_search.dart';
import 'package:mobile_apps/src/models/product_supplier.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';
import 'package:mobile_apps/src/repositories/product_supplier_repository.dart';
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:mobile_apps/src/routes.dart';

class ListProdukWidget extends StatefulWidget {
  final String idSupplier;
  final String namaSupplier;

  const ListProdukWidget({Key key, @required this.idSupplier, @required this.namaSupplier})
      : super(key: key);
  @override
  _ListProdukWidgetState createState() => _ListProdukWidgetState();
}

class _ListProdukWidgetState extends State<ListProdukWidget> {
  String _search;
  bool descending;
  String fieldSelected;
  ProductSupplierRepository barangSupplierRepo;
  Query barangSupplierCollections;

  final List<String> field = ['stok', 'harga'];

  @override
  void initState() {
    _search = '';
    barangSupplierRepo = ProductSupplierRepository();
    barangSupplierCollections = barangSupplierRepo.allProductsFromSupplier(
        idSupplier: widget.idSupplier);
    descending = true;
    super.initState();
  }

  void onChange(String s) {
    setState(() {
      _search = s;
    });
  }

  @override
  Widget build(BuildContext context) {
    if (fieldSelected != null) {
      barangSupplierCollections = barangSupplierRepo.allProductsFromSupplier(
          idSupplier: widget.idSupplier);
      barangSupplierCollections = barangSupplierCollections
          .orderBy(fieldSelected, descending: descending);
    } else {
      barangSupplierCollections = barangSupplierRepo.allProductsFromSupplier(
          idSupplier: widget.idSupplier);
    }
    return Column(
        children: <Widget>[
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                'Produk Tersedia',
                style: Theme.of(context).textTheme.headline5.copyWith(color: Colors.white)
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.end,
                children: <Widget>[
                  IconButton(
                    icon: Icon(Icons.sort),
                    onPressed: () {
                      showModalBottomSheet(
                          context: context,
                          builder: (context) => sortModal(),
                          backgroundColor: Colors.transparent,
                          isScrollControlled: true);
                    },
                    color: Colors.white,
                  ),
                  IconButton(
                    icon: Icon(Icons.filter_list),
                    onPressed: () {},
                    color: Colors.white,
                  ),
                ],
              ),
            ],
          ),
          InputSearch(
            onChange: onChange,
          ),
          Expanded(
            child: Container(
              constraints: kIsWeb ? BoxConstraints(maxWidth: 600.0) : null,
              margin: kIsWeb
                  ? EdgeInsets.symmetric(vertical: 20)
                  : EdgeInsets.only(top: 20),
              color: Colors.transparent,
              child: StreamBuilder<QuerySnapshot>(
                  stream: barangSupplierCollections.snapshots(),
                  builder: (context, snapshot) {
                    if (snapshot.hasError) {
                      SchedulerBinding.instance.addPostFrameCallback((_) {
                        Scaffold.of(context).showErrorSnackBar(
                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                      });
                    }
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return Center(child: CircularProgressIndicator());
                    }
                    final items = barangSupplierRepo.allProducts(snapshot);
                    return ListView.builder(
                      itemBuilder: (BuildContext context, int index) {
                        return _Produk(
                            product: items[index],
                            idSupplier: widget.idSupplier,
                            namaSupplier: widget.namaSupplier,
                            search: _search,
                            );
                      },
                      itemCount: items.length,
                      shrinkWrap: true,
                    );
                  }),
            ),
          )
        ],
    );
  }

  Widget sortModal() {
    return StatefulBuilder(
      builder: (context, setStateModal) {
        return Container(
          height: MediaQuery.of(context).size.height / 3,
          padding: EdgeInsets.symmetric(horizontal: 10),
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.only(
              topLeft: const Radius.circular(25.0),
              topRight: const Radius.circular(25.0),
            ),
          ),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  Expanded(
                    flex: 2,
                    child: DropdownButton<String>(
                        value: fieldSelected,
                        style: TextStyle(
                            color: ColorConstants.redPrimary,
                            fontSize: 18,
                            fontWeight: FontWeight.w700,
                            decorationStyle: TextDecorationStyle.solid,
                            decorationColor: ColorConstants.bluePrimary,
                            decorationThickness: 2),
                        icon: Icon(Icons.arrow_downward,
                            color: ColorConstants.bluePrimary),
                        underline: Container(
                          height: 2,
                          color: ColorConstants.bluePrimary,
                        ),
                        items: field
                            .map<DropdownMenuItem<String>>(
                                (String e) => DropdownMenuItem<String>(
                                      child: Text(
                                        e.toUpperCase(),
                                      ),
                                      value: e,
                                    ))
                            .toList(),
                        hint: Text(
                          'Sort by',
                          style: TextStyle(color: ColorConstants.bluePrimary),
                        ),
                        iconSize: 24,
                        onChanged: (val) {
                          setStateModal(() {
                            fieldSelected = val;
                          });
                          setState(() {
                            fieldSelected = val;
                          });
                        }),
                  ),
                  Expanded(
                    flex: 2,
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        RadioListTile<bool>(
                          title: const Text('Ascending'),
                          value: false,
                          groupValue: descending,
                          onChanged: (bool value) {
                            setStateModal(() {
                              descending = value;
                              fieldSelected = fieldSelected ?? field[0];
                            });
                            setState(() {
                              fieldSelected = fieldSelected ?? field[0];
                              descending = value;
                            });
                          },
                        ),
                        RadioListTile<bool>(
                          title: const Text('Descending'),
                          value: true,
                          groupValue: descending,
                          onChanged: (bool value) {
                            setStateModal(() {
                              descending = value;
                              fieldSelected = fieldSelected ?? field[0];
                            });
                            setState(() {
                              fieldSelected = fieldSelected ?? field[0];
                              descending = value;
                            });
                          },
                        ),
                      ],
                    ),
                  )
                ],
              ),
              SizedBox(
                  width: double.infinity,
                  child: RaisedButton(
                    onPressed: () {
                      setStateModal(() {
                        fieldSelected = null;
                      });
                      setState(() {
                        fieldSelected = null;
                      });
                    },
                    child: Text('Clear'),
                    color: ColorConstants.redPrimary,
                    textColor: Colors.white,
                  ))
            ],
          ),
        );
      },
    );
  }
}

class _Produk extends StatelessWidget {
  final ProductSupplier product;
  final String idSupplier;
  final String namaSupplier;
  final String search;

  const _Produk(
      {Key key,
      @required this.product,
      @required this.idSupplier,
      @required this.namaSupplier,
      this.search})
      : assert(product != null),
        super(key: key);
  @override
  Widget build(BuildContext context) {
    final itemRepo = ItemRepository();
    return Container(
      child: StreamBuilder<DocumentSnapshot>(
          stream:
              itemRepo.itemDocumentFromPath(path: product.idItem).snapshots(),
          builder: (context, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            final item = itemRepo.item(snapshot);
            var searchTarget = (item.nama ?? '') + (item.deskripsi ?? '') + (item.manfaat ?? '');
            var shouldShow = searchTarget.toLowerCase().contains(search.toLowerCase());
            return GestureDetector(
              onTap: () {
                Navigator.of(context).pushNamed(AppRoute.detailProductSupplier(
                    idSupplier: idSupplier, idBarang: product.id));
              },
              child: shouldShow ? SizedBox(
                height: MediaQuery.of(context).size.height / 7,
                child:
                CardItemSupplier(
                harga: product.harga,
                itemName: item.nama,
                stock: product.stok,
                supplierName: namaSupplier,
                itemImage: item.url,
              )) : Container(),
            );
          }),
    );
  }
}
