import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';

// Extension import
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/repositories/supplier_repository.dart';
import 'package:mobile_apps/src/screens/supplier/supplier.dart';

import '../../routes.dart';

class ListSupplierWidget extends StatefulWidget {
  @override
  _ListSupplierWidgetState createState() => _ListSupplierWidgetState();
}

class _ListSupplierWidgetState extends State<ListSupplierWidget> {
  List semuaSupplier = [];
  @override
  Widget build(BuildContext context) {
    final repository = SupplierRepository();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: Text(
                  'Supplier',
                  style: TextStyle(fontWeight: FontWeight.bold, fontSize: 20),
                )),
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pushNamed(AppRoute.allSuppliers);
                  },
                  child: Text(
                    'Lihat Semua',
                    style: TextStyle(color: ColorConstants.redPrimary),
                  ),
                )),
          ],
        ),
        StreamBuilder(
          stream: repository.supplierCollections.snapshots(),
          builder: (_, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            semuaSupplier = repository.semuaSupplier(snapshot).take(5).toList();
            return Container(
              height: MediaQuery.of(context).size.height * 0.265,
              child: ListView.builder(
                itemBuilder: (BuildContext context, int index) {
                  return SupplierWidget(
                    supplier: semuaSupplier[index],
                  );
                },
                itemCount: semuaSupplier.length,
                shrinkWrap: true,
                scrollDirection: Axis.horizontal,
              ),
            );
          },
        ),
      ],
    );
  }
}
