import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:intl/intl.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/appbar/sigapappbar.dart';
import 'package:mobile_apps/src/models/product_supplier.dart';
import 'package:mobile_apps/src/repositories/item_repository.dart';
import 'package:mobile_apps/src/repositories/product_supplier_repository.dart';
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/repositories/supplier_repository.dart';
import 'package:mobile_apps/src/routes.dart';
import 'package:mobile_apps/src/screens/home/kontak/kontak.dart';
import 'package:mobile_apps/src/common/functions.dart';

class DetailProductSupplier extends StatefulWidget {
  final String idSupplier;
  final String idBarang;
  DetailProductSupplier({@required this.idSupplier, @required this.idBarang});
  @override
  _DetailProductSupplierState createState() => _DetailProductSupplierState();
}

class _DetailProductSupplierState extends State<DetailProductSupplier> {
  int jumlahPembelian = 0;
  ProductSupplier product;
  bool berhasilPesan = false;
  @override
  Widget build(BuildContext context) {
    final repository = ProductSupplierRepository();
    return Scaffold(
      appBar: SigapAppBar(
        title: 'Detail Produk',
      ),
      body: StreamBuilder(
          stream: repository
              .oneProductFromSupplier(
                  idSupplier: widget.idSupplier, idProduct: widget.idBarang)
              .snapshots(),
          builder: (context, snapshot) {
            if (snapshot.hasError) {
              SchedulerBinding.instance.addPostFrameCallback((_) {
                Scaffold.of(context).showErrorSnackBar(
                    'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
              });
            }
            ;
            if (snapshot.connectionState == ConnectionState.waiting) {
              return Center(child: CircularProgressIndicator());
            }
            ;
            product = repository.product(snapshot);
            final itemRepository = ItemRepository();
            final supplierRepository = SupplierRepository();
            return StreamBuilder(
                stream: itemRepository
                    .itemDocumentFromPath(path: product.idItem)
                    .snapshots(),
                builder: (context, itemSnapshot) {
                  if (itemSnapshot.hasError) {
                    SchedulerBinding.instance.addPostFrameCallback((_) {
                      Scaffold.of(context).showErrorSnackBar(
                          'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                    });
                  }
                  ;
                  if (itemSnapshot.connectionState == ConnectionState.waiting) {
                    return Center(child: CircularProgressIndicator());
                  }
                  ;
                  final item = itemRepository.item(itemSnapshot);
                  return ListView(
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.only(top: 33, left: 19, bottom: 5),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: <Widget>[
                            Text(
                              item.nama,
                              style: TextStyle(
                                  fontSize: 20, fontWeight: FontWeight.bold),
                              overflow: TextOverflow.ellipsis,
                            ),
                            Text(
                              'Dientry ${DateFormat('dd MMMM yyy hh:mm').format(product.timestamp)} oleh ${product.admin}',
                              style: TextStyle(
                                  color: ColorConstants.muteText, fontSize: 12),
                            ),
                          ],
                        ),
                      ),
                      SizedBox(
                        height: 194,
                        child: kIsWeb
                            ? Container(
                                decoration: BoxDecoration(
                                    image: DecorationImage(
                                        image: NetworkImage(item.url),
                                        fit: BoxFit.scaleDown)),
                              )
                            : CachedNetworkImage(
                                imageUrl: item.url,
                                imageBuilder: (context, imageProvider) =>
                                    Container(
                                  decoration: BoxDecoration(
                                      image: DecorationImage(
                                          image: imageProvider,
                                          fit: BoxFit.scaleDown)),
                                ),
                                placeholder: (context, _) => const Center(
                                    child: CircularProgressIndicator()),
                                errorWidget: (context, url, error) => Container(
                                  decoration: BoxDecoration(
                                      image: DecorationImage(
                                          image: AssetImage(
                                              'assets/images/medical-item-placeholder.png'),
                                          fit: BoxFit.scaleDown)),
                                ),
                              ),
                      ),
                      Padding(
                        padding: EdgeInsets.symmetric(
                            vertical: MarginConstants.verticalFromScreen,
                            horizontal: MarginConstants.horizontalFromScreen),
                        child: Card(
                          child: Container(
                            margin: EdgeInsets.symmetric(
                                vertical: 23,
                                horizontal:
                                    MarginConstants.horizontalFromScreen),
                            child: Column(
                              mainAxisAlignment: MainAxisAlignment.spaceAround,
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: <Widget>[
                                Text(
                                  "${NumberFormat.simpleCurrency(locale: 'id').format(product.harga)}/pcs",
                                  style: TextStyle(
                                      color: ColorConstants.redSecondary,
                                      fontWeight: FontWeight.bold,
                                      fontSize: 20),
                                ),
                                _description('Stok', '${product.stok} buah'),
                                _description(
                                    'Spesifikasi', '${product.spesifikasi}'),
                                _description('Manfaat', '${item.manfaat}')
                              ],
                            ),
                          ),
                        ),
                      ),
                      Padding(
                          padding: EdgeInsets.only(
                              bottom: MarginConstants.verticalFromScreen),
                          child: Card(
                            child: Container(
                              margin: EdgeInsets.symmetric(
                                  vertical: 26, horizontal: 32),
                              child: StreamBuilder(
                                  stream: supplierRepository
                                      .supplierDocument(
                                          idSupplier: widget.idSupplier)
                                      .snapshots(),
                                  builder: (context, supplierSnapshot) {
                                    if (supplierSnapshot.hasError) {
                                      SchedulerBinding.instance
                                          .addPostFrameCallback((_) {
                                        Scaffold.of(context).showErrorSnackBar(
                                            'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                                      });
                                    }
                                    ;
                                    if (supplierSnapshot.connectionState ==
                                        ConnectionState.waiting) {
                                      return Center(
                                          child: CircularProgressIndicator());
                                    }
                                    ;
                                    final supplier = supplierRepository
                                        .supplier(supplierSnapshot);
                                    return Column(
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: <Widget>[
                                        Text(
                                          supplier.nama,
                                          style: TextStyle(
                                            fontSize: 20,
                                            fontWeight: FontWeight.bold,
                                          ),
                                          overflow: TextOverflow.ellipsis,
                                        ),
                                        Container(
                                          margin:
                                              EdgeInsets.symmetric(vertical: 4),
                                          child: Column(
                                            mainAxisAlignment:
                                                MainAxisAlignment.center,
                                            crossAxisAlignment:
                                                CrossAxisAlignment.start,
                                            children: <Widget>[
                                              if (supplier.telepon != null)
                                                KontakButton(
                                                    Icon(Icons.phone_in_talk),
                                                    'Telepon ${supplier.telepon}',
                                                    () => launchURL(
                                                          supplier.telepon,
                                                          scheme: 'tel',
                                                        )),
                                              if (supplier.telepon != null)
                                                KontakButton(
                                                    Icon(MdiIcons.whatsapp),
                                                    'WhatsApp ${supplier.telepon}',
                                                    () => launchURL(
                                                          '//wa.me/${cleanPhoneNumber(supplier.telepon)}',
                                                          scheme: 'https',
                                                        )),
                                            ],
                                          ),
                                        ),
                                        InkWell(
                                            child: Container(
                                                padding: EdgeInsets.symmetric(
                                                    vertical: 10),
                                                decoration: BoxDecoration(
                                                    color: Colors.transparent,
                                                    borderRadius:
                                                        BorderRadius.circular(
                                                            50),
                                                    border: Border.all(
                                                        color: ColorConstants
                                                            .redPrimary)),
                                                child: Center(
                                                  child: Text(
                                                      'Lihat Detail Supplier',
                                                      style: TextStyle(
                                                          color: ColorConstants
                                                              .redPrimary,
                                                          fontWeight:
                                                              FontWeight.w600,
                                                          fontSize: 16)),
                                                )),
                                            onTap: () => Navigator.of(context)
                                                .pushNamed(AppRoute.supplier(
                                                    idSupplier:
                                                        widget.idSupplier)))
                                      ],
                                    );
                                  }),
                            ),
                          )),
                      Container(
                        width: MediaQuery.of(context).size.width,
                        margin: EdgeInsets.only(top: 13),
                        padding:
                            EdgeInsets.symmetric(vertical: 16, horizontal: 20),
                        decoration: BoxDecoration(color: Colors.white),
                        child: InkWell(
                            onTap: () => showModalBottomSheet(
                                context: context,
                                builder: (context) => sortModal(),
                                backgroundColor: Colors.transparent,
                                isScrollControlled: true),
                            child: Container(
                              decoration: BoxDecoration(
                                color: ColorConstants.redPrimary,
                                borderRadius: BorderRadius.circular(50),
                              ),
                              padding: EdgeInsets.symmetric(vertical: 10),
                              child: Text('Tambah Ke Keranjang',
                                  textAlign: TextAlign.center,
                                  style: TextStyle(
                                      fontWeight: FontWeight.bold,
                                      color: Colors.white,
                                      fontSize: 16)),
                            )),
                      )
                    ],
                  );
                });
          }),
    );
  }

  Widget _description(String title, String description) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Text(
          title,
          style: TextStyle(fontWeight: FontWeight.w600, fontSize: 16),
        ),
        Text(
          description,
          style: TextStyle(fontSize: 16),
        )
      ],
    );
  }

  Widget sortModal() {
    return StatefulBuilder(
      builder: (context, setStateModal) {
        return Container(
          height: MediaQuery.of(context).size.height / 3,
          padding: EdgeInsets.only(top: 37),
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.only(
              topLeft: const Radius.circular(25.0),
              topRight: const Radius.circular(25.0),
            ),
          ),
          child: Stack(
            children: <Widget>[
              Opacity(
                  opacity: berhasilPesan ? 1 : 0,
                  child: InkWell(
                    onTap: () {
                      setStateModal(() {
                        berhasilPesan = false;
                      });
                    },
                    child: Center(
                        child: Row(
                      children: <Widget>[
                        Expanded(
                            child: Icon(
                          Icons.shopping_cart,
                          size: 100,
                          color: ColorConstants.redPrimary,
                        )),
                        Expanded(
                            child: Text(
                                'Produk berhasil ditambahkan ke keranjang!',
                                style: TextStyle(fontSize: 16)))
                      ],
                    )),
                  )),
              Opacity(
                opacity: berhasilPesan ? 0 : 1,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Container(
                        margin: EdgeInsets.only(left: 25),
                        child: Text('Masukkan kuantitas produk')),
                    Container(
                      margin:
                          EdgeInsets.symmetric(horizontal: 25, vertical: 20),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: <Widget>[
                          Text('Jumlah',
                              style: TextStyle(
                                  fontWeight: FontWeight.w600, fontSize: 16)),
                          Row(
                            children: <Widget>[
                              InkWell(
                                onTap: () {
                                  setStateModal(() {
                                    jumlahPembelian = jumlahPembelian > 0
                                        ? jumlahPembelian - 1
                                        : jumlahPembelian;
                                  });
                                },
                                child: Container(
                                  height: 30,
                                  width: 30,
                                  margin: EdgeInsets.only(right: 8),
                                  decoration: BoxDecoration(
                                    color: ColorConstants.redPrimary,
                                    borderRadius: BorderRadius.circular(5),
                                  ),
                                  child: Center(
                                      child: Text(
                                    '-',
                                    style: TextStyle(
                                        color: Colors.white,
                                        fontWeight: FontWeight.bold),
                                  )),
                                ),
                              ),
                              Container(
                                  margin: EdgeInsets.only(right: 8),
                                  child: Text(
                                    '${jumlahPembelian}',
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold),
                                  )),
                              InkWell(
                                onTap: () {
                                  setStateModal(() {
                                    jumlahPembelian =
                                        jumlahPembelian < product.stok
                                            ? jumlahPembelian + 1
                                            : jumlahPembelian;
                                  });
                                },
                                child: Container(
                                  height: 30,
                                  width: 30,
                                  decoration: BoxDecoration(
                                    color: ColorConstants.redPrimary,
                                    borderRadius: BorderRadius.circular(5),
                                  ),
                                  child: Center(
                                      child: Text('+',
                                          style: TextStyle(
                                              color: Colors.white,
                                              fontWeight: FontWeight.bold))),
                                ),
                              ),
                              Divider(
                                color: ColorConstants.grayPrimary
                                    .withOpacity(0.15),
                                thickness: 1,
                                height: 1,
                              ),
                            ],
                          )
                        ],
                      ),
                    ),
                    Divider(
                      color: ColorConstants.grayPrimary.withOpacity(0.15),
                      thickness: 1,
                      height: 1,
                    ),
                    Container(
                      margin:
                          EdgeInsets.symmetric(horizontal: 25, vertical: 20),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: <Widget>[
                          Text('Total',
                              style: TextStyle(
                                  fontWeight: FontWeight.w600, fontSize: 16)),
                          Text('Rp ${jumlahPembelian * product.harga}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w600, fontSize: 16))
                        ],
                      ),
                    ),
                    Expanded(
                      child: InkWell(
                        onTap: () {
                          setStateModal(() {
                            berhasilPesan = true;
                          });
                        },
                        child: Container(
                            padding: EdgeInsets.symmetric(vertical: 21),
                            color: ColorConstants.redPrimary,
                            child: Center(
                              child: Text(
                                'Tambah ke Keranjang',
                                style: TextStyle(
                                    color: Colors.white,
                                    fontSize: 16,
                                    fontWeight: FontWeight.bold),
                              ),
                            )),
                      ),
                    )
                  ],
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
