import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/models/supplier.dart';
import 'package:mobile_apps/src/routes.dart';

class SupplierWidget extends StatelessWidget {
  final Supplier supplier;

  const SupplierWidget({Key key, @required this.supplier})
      : assert(supplier != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Card(
        child: Padding(
      padding: EdgeInsets.only(top: 20),
      child: FittedBox(
        fit: BoxFit.fitHeight,
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.center,
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Container(
                width: 380,
                child: ListTile(
                    title: Text(supplier.nama,
                        style: TextStyle(
                            fontSize: 16, fontWeight: FontWeight.w600)),
                    subtitle: Text('${supplier.alamat}',
                        style: TextStyle(fontSize: 12)),
                    trailing: Icon(Icons.share)),
              ),
              Padding(
                padding: const EdgeInsets.symmetric(
                    horizontal: MarginConstants.horizontalFromScreen),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: <Widget>[
                    Icon(
                      Icons.store,
                      color: Colors.black,
                    ),
                    Padding(
                      padding: EdgeInsets.only(left: 4),
                      child: Text('Perusahaan Terbuka'),
                    )
                  ],
                ),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Padding(
                    padding:
                        EdgeInsets.symmetric(horizontal: 16.0, vertical: 20.0),
                    child: RoundedButton(text: 'Subscribe',
                        elevation: 0.0,
                        padding: EdgeInsets.symmetric(horizontal: 50.0),
                        radius: 32.0,
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: 12.0,
                            fontWeight: FontWeight.bold),
                        onPressed: () {}),
                  ),
                  Padding(
                    padding:
                        EdgeInsets.symmetric(horizontal: 16.0, vertical: 20.0),
                    child: RoundedButton(text: 'Detail',
                        elevation: 0.0,
                        padding: EdgeInsets.symmetric(horizontal: 66.0),
                        radius: 32.0,
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: 12.0,
                            fontWeight: FontWeight.bold), onPressed: () {
                      Navigator.of(context).pushNamed(AppRoute.supplier(
                        idSupplier: supplier.id,
                      ));
                    }),
                  ),
                ],
              ),
            ]),
      ),
    ));
  }
}
