import 'package:flutter/material.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/screens/supplier/dokumen.dart';
import 'package:mobile_apps/src/screens/supplier/ulasan.dart';
import 'package:mobile_apps/src/screens/supplier/list_produk.dart';

class SupplierTabs extends StatefulWidget {
  final fillPercent = 65.23;
  final String idSupplier;
  final String namaSupplier;

  SupplierTabs({@required this.idSupplier, @required this.namaSupplier});

  @override
  _SupplierTabsState createState() => _SupplierTabsState();
}

class _SupplierTabsState extends State<SupplierTabs>
    with SingleTickerProviderStateMixin {
  TabController _tabController;
  @override
  void initState() {
    _tabController = TabController(vsync: this, length: 4);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final fillStop = (100 - widget.fillPercent) / 100;
    final tabTextStyle = TextStyle(
        fontSize: 16.0, fontWeight: FontWeight.bold, color: Colors.white);
    return SizedBox(
        height: MediaQuery.of(context).size.height * 0.75,
        child: Container(
            padding: EdgeInsets.only(
                left: MarginConstants.horizontalFromScreen + 5,
                right: MarginConstants.horizontalFromScreen + 5,
                top: MarginConstants.verticalFromScreen + 5),
            decoration: BoxDecoration(
                gradient: LinearGradient(colors: [
              ColorConstants.redSecondary,
              ColorConstants.redSecondary,
              Colors.white,
              Colors.white
            ], stops: [
              0.0,
              fillStop,
              fillStop,
              1
            ], end: Alignment.bottomCenter, begin: Alignment.topCenter)),
            child: Column(children: <Widget>[
              TabBar(
                indicatorSize: TabBarIndicatorSize.tab,
                indicatorColor: Colors.white,
                isScrollable: true,
                controller: _tabController,
                tabs: [
                  Container(
                      width: MediaQuery.of(context).size.width / 4.5,
                      child: Tab(icon: Text('Produk', style: tabTextStyle))),
                  Container(
                      width: MediaQuery.of(context).size.width / 4.5,
                      child:
                          Tab(icon: Text('Rekomendasi', style: tabTextStyle))),
                  Container(
                      width: MediaQuery.of(context).size.width / 4.5,
                      child: Tab(icon: Text('Ulasan', style: tabTextStyle))),
                  Container(
                      width: MediaQuery.of(context).size.width / 4.5,
                      child: Tab(icon: Text('Dokumen', style: tabTextStyle))),
                ],
              ),
              Expanded(
                  child: TabBarView(
                controller: _tabController,
                children: <Widget>[
                  Container(
                    margin: EdgeInsets.symmetric(
                      horizontal: MarginConstants.horizontalFromScreen,
                      vertical: MarginConstants.verticalFromScreen,
                    ),
                    child: ListProdukWidget(
                        idSupplier: widget.idSupplier,
                        namaSupplier: widget.namaSupplier),
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(
                      horizontal: MarginConstants.horizontalFromScreen,
                      vertical: MarginConstants.verticalFromScreen,
                    ),
                    child: ListRekomendasiWidget(widget.idSupplier),
                  ),
                  Container(
                      margin: EdgeInsets.symmetric(
                        horizontal: MarginConstants.horizontalFromScreen,
                        vertical: MarginConstants.verticalFromScreen,
                      ),
                      child: ListUlasanWidget(widget.idSupplier)),
                  Container(
                      margin: EdgeInsets.symmetric(
                        horizontal: MarginConstants.horizontalFromScreen,
                        vertical: MarginConstants.verticalFromScreen,
                      ),
                      child: ListDokumenWidget(widget.idSupplier)),
                ],
              ))
            ])));
  }

  @override
  void dispose() {
    _tabController.dispose();
    super.dispose();
  }
}
