import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:mobile_apps/src/common/constants.dart';
import 'package:mobile_apps/src/components/buttons/buttons.dart';
import 'package:mobile_apps/src/components/cards/cards.dart';
import 'package:mobile_apps/src/extensions/scaffold_extension.dart';
import 'package:mobile_apps/src/repositories/ulasan_repositories.dart';
import 'package:mobile_apps/src/screens/supplier/ulasan/form_ulasan.dart';

class ListUlasanWidget extends StatelessWidget {
  final String idSupplier;
  final String title;

  const ListUlasanWidget(this.idSupplier, {this.title = 'Ulasan Pembeli'});
  @override
  Widget build(BuildContext context) {
    return _BaseListUlasanWidget(idSupplier, title,
        collection: 'ulasan',
        button: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Padding(
                  padding: EdgeInsets.only(top: 20.0, bottom: 12.0),
                  child: Text('Sudah pernah membeli produk dari supplier ini?',
                      style: Theme.of(context).textTheme.subtitle2)),
              RoundedButton(
                padding: EdgeInsets.symmetric(horizontal: 40.0, vertical: 8.0),
                child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    mainAxisSize: MainAxisSize.min,
                    children: <Widget>[
                      Padding(
                          padding: EdgeInsets.only(right: 12.0),
                          child: Icon(
                            Icons.add_circle_outline,
                            color: Colors.white,
                          )),
                      Text(
                        'Buat Ulasan Baru',
                        style: Theme.of(context)
                            .textTheme
                            .headline6
                            .copyWith(color: Colors.white),
                      )
                    ]),
                color: ColorConstants.redSecondary,
                radius: 32.0,
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                        builder: (context) => UlasanInput(
                              id: idSupplier,
                            )),
                  );
                },
              ),
            ]));
  }
}

class ListRekomendasiWidget extends StatelessWidget {
  final String idSupplier;
  final String title;
  final Color leftDecorationColor;

  const ListRekomendasiWidget(this.idSupplier,
      {this.title = 'Direkomendasikan oleh',
      this.leftDecorationColor = ColorConstants.muteText});

  @override
  Widget build(BuildContext context) {
    return _BaseListUlasanWidget(idSupplier, title,
        collection: 'rekomendasi', leftDecorationColor: leftDecorationColor);
  }
}

class _BaseListUlasanWidget extends StatefulWidget {
  final String idSupplier;
  final String collection;
  final String title;
  final Color leftDecorationColor;
  final Widget button;

  const _BaseListUlasanWidget(this.idSupplier, this.title,
      {@required this.collection, this.leftDecorationColor, this.button});

  @override
  __BaseListUlasanWidgetState createState() => __BaseListUlasanWidgetState();
}

class __BaseListUlasanWidgetState extends State<_BaseListUlasanWidget> {
  bool descending;
  UlasanRepository ulasanRepo;
  Query ulasanCollections;

  @override
  void initState() {
    ulasanRepo = UlasanRepository();
    ulasanCollections = ulasanRepo.ulasanSupplierCollections(
        widget.idSupplier, widget.collection);
    descending = true;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    ulasanCollections = ulasanRepo.ulasanSupplierCollections(
        widget.idSupplier, widget.collection);
    ulasanCollections =
        ulasanCollections.orderBy('timestamp', descending: descending);
    return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          if (widget.title != null)
            Padding(
                padding: EdgeInsets.only(bottom: 12.0),
                child: Text(
                  widget.title,
                  style: Theme.of(context)
                      .textTheme
                      .headline5
                      .copyWith(color: Colors.white),
                )),
          Flexible(
              child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Flexible(
                  child: StreamBuilder(
                stream: ulasanCollections.snapshots(),
                builder: (_, snapshot) {
                  if (snapshot.hasError) {
                    SchedulerBinding.instance.addPostFrameCallback((_) {
                      Scaffold.of(context).showErrorSnackBar(
                          'Oops! Ada sesuatu yang salah, mohon coba lagi ya.');
                    });
                  }
                  if (snapshot.connectionState == ConnectionState.waiting) {
                    return Center(child: CircularProgressIndicator());
                  }
                  var allUlasan = ulasanRepo.allUlasan(snapshot);
                  if (allUlasan.isEmpty) {
                    return Padding(
                        padding: EdgeInsets.only(bottom: 64.0),
                        child: Card(
                            child: Container(
                                width: double.infinity,
                                padding: EdgeInsets.all(12.0),
                                child: Text(
                                    "Belum ada ${widget.collection == 'rekomendasi' ? 'rekomendasi' : 'ulasan'}.",
                                    style: Theme.of(context)
                                        .textTheme
                                        .subtitle1))));
                  }
                  return ListView.builder(
                    itemBuilder: ((context, index) {
                      var ulasan = allUlasan[index];
                      Widget card = GenericCard(
                        head:
                            "${ulasan.displayDate}${widget.collection == 'rekomendasi' ? ' oleh Admin' : ''}",
                        title: ulasan.nama,
                        subtitle: ulasan.jabatan,
                        body: ulasan.body,
                      );
                      if (widget.leftDecorationColor != null) {
                        card = StackOfCards(
                          num: 2,
                          child: card,
                          color: widget.leftDecorationColor,
                          offset: 15.0,
                        );
                      }
                      return card;
                    }),
                    itemCount: allUlasan.length,
                    shrinkWrap: true,
                    scrollDirection: Axis.vertical,
                  );
                },
              )),
              if (widget.button != null) widget.button,
            ],
          ))
        ]);
  }
}
