import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:mobile_apps/src/common/constants.dart';

class AppColors {
  static const Color indigo = Color(0xFF096B91);
  static const Color pink = Color(0xFFEDD7D7);
  static const Color bluePrimary = Color(0xFF007AFF);
  static const Color blueAlternative = Color(0xFF82C5E6);

  static const Color redPrimary = Color(0xFFD62C2C);
  static const Color redSecondary = Color(0xFFE16E6E);
  static const Color redTertiary = Color(0xFFEDD7D7);
}

class AppTheme {
  static final TextTheme baseTextTheme = GoogleFonts.poppinsTextTheme().apply(
    bodyColor: Colors.black,
    displayColor: Colors.black,
  );

  static final TextTheme textTheme = baseTextTheme.copyWith(
    subtitle2:
        baseTextTheme.subtitle2.copyWith(color: ColorConstants.grayPrimary),
    headline5: baseTextTheme.headline5.copyWith(fontWeight: FontWeight.bold),
    headline6: baseTextTheme.headline6.copyWith(fontWeight: FontWeight.bold),
  );

  static ThemeData _customThemeData(ThemeData base) {
    final colorScheme = ColorScheme.light().copyWith(
      primary: AppColors.redPrimary,
      primaryVariant: AppColors.redSecondary,
    );
    return base.copyWith(
      // Somehow primaryColor is used on icon background
      primaryColor: Colors.white,
      primaryColorLight: AppColors.redSecondary,
      primaryColorDark: AppColors.redPrimary,
      primaryTextTheme: textTheme,
      textTheme: textTheme,
      accentColor: AppColors.redTertiary,
      colorScheme: colorScheme,
      appBarTheme: AppBarTheme().copyWith(
        color: Colors.white,
        iconTheme: IconThemeData().copyWith(color: Colors.black),
      ),
      iconTheme: IconThemeData().copyWith(
        color: Colors.black12,
      ),
    );
  }

  static ThemeData light() => _customThemeData(ThemeData.light());

  static ThemeData dark() => _customThemeData(ThemeData.dark());
}
