#!/usr/bin/env python3
# Please set the default credentials
# GOOGLE_APPLICATION_CREDENTIALS=service-account.json
import os
import json
import firebase_admin

from firebase_admin import credentials
from firebase_admin import firestore
from google.cloud.firestore_v1 import (
    CollectionReference,
    DocumentReference,
    DocumentSnapshot,
)

cred = credentials.ApplicationDefault()

firebase_admin.initialize_app(cred)
client = firestore.client()


def main():
    rename_suppliers_to_supplier()

def rename_suppliers_to_supplier():
    suppliers_collection_ref = client.collection('waspada/covid19/suppliers')
    supplier_refs = suppliers_collection_ref.list_documents()

    for supplier_ref in supplier_refs:
        supplier_snapshot = supplier_ref.get()
        print(supplier_ref.path)
        print(supplier_snapshot.to_dict())
        print([suppliers_collection_ref for supplier_subcollection_ref in supplier_ref.collections()])

def copy_document_path(source_document_path: str,
                       target_document_path: str,
                       rename_subcollections=None,
                       rename_fields=None):
    source_document_ref = client.document(source_document_path)
    target_document_ref = client.document(target_document_path)

    copy_document_ref(source_document_ref, target_document_ref,
                      rename_subcollections=rename_subcollections,
                      rename_fields=rename_fields)

def copy_document_ref(source_document_ref: DocumentReference,
                      target_document_ref: DocumentReference,
                      rename_subcollections=None,
                      rename_fields=None):
    source_document_dict = source_document_ref.get().to_dict()

    if rename_fields is not None:
        for old, new in rename_fields.items():
            if old in source_document_dict:
                source_document_dict[new] = source_document_dict[old]
                del source_document_dict[old]

    target_document_ref.set(source_document_dict)

    source_subcollections_ref = source_document_ref.collections()

    for source_subcollection_ref in source_subcollections_ref:
        subcollection_id = source_subcollection_ref.id

        if rename_subcollections is not None and subcollection_id in rename_subcollections:
            subcollection_id = rename_subcollections[subcollection_id]

        target_subcollection_ref = target_document_ref.collection(subcollection_id)

        copy_collection_ref(source_subcollection_ref, target_subcollection_ref,
                            rename_subcollections=rename_subcollections,
                            rename_fields=rename_fields)

def copy_collection_path(source_collection_path: str,
                         target_collection_path: str,
                         rename_subcollections=None,
                         rename_fields=None):
    source_collection_ref = client.collection(source_collection_path)
    target_collection_ref = client.collection(target_collection_path)

    copy_collection_ref(source_collection_ref, target_collection_ref,
                        rename_subcollections=rename_subcollections,
                        rename_fields=rename_fields)

def copy_collection_ref(source_collection_ref: CollectionReference,
                        target_collection_ref: CollectionReference,
                        rename_subcollections=None,
                        rename_fields=None):
    source_documents_ref = source_collection_ref.list_documents()
    for source_document_ref in source_documents_ref:
        target_document_ref = target_collection_ref.document(source_document_ref.id)

        copy_document_ref(source_document_ref, target_document_ref,
                          rename_subcollections=rename_subcollections,
                          rename_fields=rename_fields)


if __name__ == '__main__':
    main()
